@@ -1,6 +1,6 @@
 #! /bin/sh
 :
-#ident	"@(#)smail/conf/lib:RELEASE-3_2_0_118:mkdefs.sh,v 1.76 2004/02/08 18:29:26 woods Exp"
+#ident	"@(#)smail/conf/lib:RELEASE-3_2_0_119:mkdefs.sh,v 1.79 2004/07/29 19:11:06 woods Exp"
 
 #    Copyright (C) 1987, 1988 Ronald S. Karr and Landon Curt Noll
 #    Copyright (C) 1992  Ronald S. Karr
@@ -113,8 +113,7 @@ VARS="\
  ALIASES_REMOVE_SENDER\
  ALIASES_TYPE\
  AUTH_DOMAINS\
- BIT_PER_CHAR\
- BYTES_PER_ALIGN\
+ BITS_PER_CHAR\
  CC\
  CHOWN\
  COMPRESS\
@@ -181,7 +180,6 @@ VARS="$VARS\
  TMP_DIR\
  UNCOMPRESS\
  UNSHAR_MAP_DIR\
- USE_ASCII\
  USE_SYMLINKS\
  UTIL_BIN_DIR\
  UUCP_NAME\
@@ -415,7 +413,11 @@ done
 case "$TEST_BASE" in
 
 "<not defined>" )
-	UTIL_PATH="$UTIL_BIN_DIR:$SMAIL_BIN_DIR"
+	if [ "$UTIL_BIN_DIR" = "$SMAIL_BIN_DIR" ]; then
+		UTIL_PATH="$UTIL_BIN_DIR"
+	else
+		UTIL_PATH="$UTIL_BIN_DIR:$SMAIL_BIN_DIR"
+	fi
 	TEST_BASE=""
 	DONT_INSTALL=""
 	;;
@@ -447,7 +449,11 @@ case "$TEST_BASE" in
 	LOG_DIR="$TEST_BASE/$LOG_DIR"
 	SECOND_CONFIG_FILE=""
 	UTIL_BIN_DIR="$TEST_BASE/$UTIL_BIN_DIR"
-	UTIL_PATH="$UTIL_BIN_DIR:$SMAIL_BIN_DIR"
+	if [ "$UTIL_BIN_DIR" = "$SMAIL_BIN_DIR" ]; then
+		UTIL_PATH="$UTIL_BIN_DIR"
+	else
+		UTIL_PATH="$UTIL_BIN_DIR:$SMAIL_BIN_DIR"
+	fi
 	TMP_DIR="$TEST_BASE/$TMP_DIR"
 	NEWALIASES=""
 	DONT_INSTALL=""
@@ -463,7 +469,11 @@ case "$TEST_BASE" in
 	LOG_DIR="$ROOT/$TEST_BASE/$LOG_DIR"
 	SECOND_CONFIG_FILE=""
 	UTIL_BIN_DIR="$ROOT/$TEST_BASE/$UTIL_BIN_DIR"
-	UTIL_PATH="$UTIL_BIN_DIR:$SMAIL_BIN_DIR"
+	if [ "$UTIL_BIN_DIR" = "$SMAIL_BIN_DIR" ]; then
+		UTIL_PATH="$UTIL_BIN_DIR"
+	else
+		UTIL_PATH="$UTIL_BIN_DIR:$SMAIL_BIN_DIR"
+	fi
 	TMP_DIR="$ROOT/$TEST_BASE/$TMP_DIR"
 	TEST_BASE="$ROOT/$TEST_BASE"
 	NEWALIASES=""
@@ -1034,7 +1044,6 @@ EOF
 sed -n 	-e 's/\([A-Z0-9_]*\)=..*/#define \1/p' \
 	-e 's/\([A-Z0-9_]*\)=$/#undef \1/p' <<EOF
 SMALL_MEMORY=$SMALL_MEMORY
-USE_ASCII=$USE_ASCII
 UUWHO_USE_DBM=$UUWHO_USE_DBM
 UUCP_ZONE=$UUCP_ZONE
 ALIASES_REMOVE_SENDER=$ALIASES_REMOVE_SENDER
@@ -1085,7 +1094,6 @@ cat <<EOF
 #define POINTER_TYPE	$POINTER_TYPE
 #define ALIGNED_TYPE	$ALIGNED_TYPE
 #define BITS_PER_CHAR	$BITS_PER_CHAR
-#define BYTES_PER_ALIGN	$BYTES_PER_ALIGN
 #define MAXINT_B10_DIGITS $MAXINT_B10_DIGITS
 #define MAXLONG_B10_DIGITS $MAXLONG_B10_DIGITS
 
