@@ -1,6 +1,6 @@
 #! /bin/sh
 :
-#ident	"@(#)smail/conf/lib:RELEASE-3_2_0_118:mkdepend.sh,v 1.15 2003/09/29 20:47:31 woods Exp"
+#ident	"@(#)smail/conf/lib:RELEASE-3_2_0_119:mkdepend.sh,v 1.16 2004/06/25 18:09:34 woods Exp"
 #
 # build a list of dependencies and insert them at the end of the make file
 #
@@ -49,12 +49,12 @@ for i in "$@"; do
 		#	# line-number "filename"
 		#
 		# use grep to avoid line-length limits in some seds
-		grep '^#[ 	]*[0-9]' |
+		grep '^#\(line\)*[ 	]*[0-9]' |
 		# the compiler with the sun 3 produces extra garbage after
 		# the quoted filename.
 		# gcc-3.2 produces these stupid "fake" filenames
 		sed -n -e '/<built-in>/d' -e '/<command line>/d' \
-			-e 's/^#[ 	]*[0-9]*[ 	]*"\(.*\)"[ 0-9]*$/\1/p' |
+			-e 's/^#\(line\)*[ 	]*[0-9]*[ 	]*"\(.*\)"[ 0-9]*$/\2/p' |
 		# remove ./ prefixes
 		sed -e 's%^\./%%' |
 		# next remove duplicates
