@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_118:addr.c,v 1.65 2004/05/30 22:50:41 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_119:addr.c,v 1.68 2004/08/23 23:18:55 woods Exp"
  */
 
 /*
@@ -663,7 +663,7 @@ check_target_and_remainder(targetp, remainderp, form)
     p = *targetp;
 #ifdef HAVE_BSD_NETWORKING
     if (*p == '[') {
-	unsigned long inet;		/* IP address */
+	in_addr_t inet;			/* IP address */
 	char *p2;			/* pointer to closing bracket (]) */
 
 	p2 = strchr(p, ']');
@@ -672,7 +672,7 @@ check_target_and_remainder(targetp, remainderp, form)
 	*p2 = ']';
 	DEBUG4(DBG_ADDR_HI, "check_target_and_remainder(%v, %v): inet addr given: [0x%lx] aka [%s]\n",
 	       *targetp, *remainderp,
-	       ntohl(inet), inet_ntoa(inet_makeaddr((unsigned long) ntohl(inet), (unsigned long) 0)));
+	       ntohl(inet), inet_ntoa(inet_makeaddr((in_addr_t) ntohl(inet), (in_addr_t) 0)));
 	if (inet == INADDR_NONE) {
 	    DEBUG2(DBG_ADDR_LO, "check_target_and_remainder(%v, %v): get_inet_addr() failed: Invalid host address literal form\n", *targetp, *remainderp);
 	    *remainderp = "Invalid host address literal form";
@@ -1458,19 +1458,97 @@ alloc_addr()
     return new;
 }
 
-#ifdef not_yet
+
+/*
+ * free_addr - free a struct addr
+ */
 void
 free_addr(done)
     struct addr *done;			/* addr struct to free */
 {
+    if (done->parent) {
+	free_addr(done->parent);
+	done->parent = NULL;
+    }
+    if (done->true_addr) {
+	free_addr(done->true_addr);
+	done->true_addr = NULL;
+    }
+    if (done->in_addr) {
+	xfree((char *) done->in_addr);
+	done->in_addr = NULL;
+    }
+    if (done->target) {
+	xfree((char *) done->target);
+	done->target = NULL;
+    }
+    if (done->remainder) {
+	xfree((char *) done->remainder);
+	done->remainder = NULL;
+    }
+    if (done->rem_prefix) {
+	xfree((char *) done->rem_prefix);
+	done->rem_prefix = NULL;
+    }
+    if (done->rem_suffix) {
+	xfree((char *) done->rem_suffix);
+	done->rem_suffix = NULL;
+    }
     if (done->work_addr) {
-	xfree(done->work_addr);
+	xfree((char *) done->work_addr);
+	done->work_addr = NULL;
+    }
+    if (done->local_name) {
+	xfree((char *) done->local_name);
+	done->local_name = NULL;
+    }
+    if (done->owner) {
+	xfree((char *) done->owner);
+	done->owner = NULL;
+    }
+    if (done->route) {
+	xfree((char *) done->route);
+	done->route = NULL;
+    }
+    if (done->next_host) {
+	xfree((char *) done->next_host);
+	done->next_host = NULL;
+    }
+    if (done->next_addr) {
+	xfree((char *) done->next_addr);
+	done->next_addr = NULL;
+    }
+    /* XXX home is not always uniquely allocated storage, but sometimes it is */
+    /* XXX do multiple addresses point to the same tphint_list? */
+    if (done->error) {
+	/* XXX what about error->message ??? */
+	xfree((char *) done->error);
+	done->error = NULL;
     }
     xfree((char *) done);
 
     return;
 }
-#endif
+
+
+/*
+ * free_addr_list - free a list of addresses
+ */
+void
+free_addr_list(donelst)
+    struct addr *donelst;		/* list of addrs to free */
+{
+    struct addr *cur;
+    struct addr *next;
+
+    for (cur = donelst; cur; cur = next) {
+	next = cur->succ;
+	free_addr(cur);
+    }
+
+    return;
+}
+
 
 /*
  * insert_addr_list - insert a list of addrs into another list
@@ -1713,10 +1791,8 @@ dump_addr_list(in)
     struct addr *in;			/* input list */
 {
     register struct addr *cur;		/* current address to process */
-    register struct addr *next;		/* next address to process */
 
-    for (cur = in; cur; cur = next) {
-	next = cur->succ;
+    for (cur = in; cur; cur = cur->succ) {
 	dump_addr(cur, "");
     }
 
@@ -1728,40 +1804,42 @@ dump_addr(cur, prefix)
     struct addr *cur;			/* a single address (succ should be NULL) */
     char *prefix;
 {
+#define X_SHOW_XALLOC(p)	(p ? (X_IS_XALLOC(p) ? "(XALLOC) " : "") : "")
+
     dprintf(errfile, "in_addr = %v\n", cur->in_addr);
     if (cur->flags || debug >= DBG_ADDR_HI)
 	dprintf(errfile, "%s    flags = 0x%lx\n", prefix, cur->flags);
     if (cur->parseflags || debug >= DBG_ADDR_HI)
 	dprintf(errfile, "%s    parseflags = 0x%x\n", prefix, cur->parseflags);
     if (cur->work_addr || debug >= DBG_ADDR_HI)
-	dprintf(errfile, "%s    work_addr = %v\n", prefix, cur->work_addr);
+	dprintf(errfile, "%s    work_addr = %s%v\n", prefix, X_SHOW_XALLOC(cur->work_addr), cur->work_addr);
     if (cur->next_host || debug >= DBG_ADDR_HI)
-	dprintf(errfile, "%s    next_host = %v\n", prefix, cur->next_host);
+	dprintf(errfile, "%s    next_host = %s%v\n", prefix, X_SHOW_XALLOC(cur->next_host), cur->next_host);
     if (cur->next_addr || debug >= DBG_ADDR_HI)
-	dprintf(errfile, "%s    next_addr = %v\n", prefix, cur->next_addr);
+	dprintf(errfile, "%s    next_addr = %s%v\n", prefix, X_SHOW_XALLOC(cur->next_addr), cur->next_addr);
     if (cur->target || debug >= DBG_ADDR_HI)
-	dprintf(errfile, "%s    target = %v\n", prefix, cur->target);
+	dprintf(errfile, "%s    target = %s%v\n", prefix, X_SHOW_XALLOC(cur->target), cur->target);
     if (cur->route || debug >= DBG_ADDR_HI)
-	dprintf(errfile, "%s    route = %v\n", prefix, cur->route);
+	dprintf(errfile, "%s    route = %s%v\n", prefix, X_SHOW_XALLOC(cur->route), cur->route);
     if (cur->remainder || debug >= DBG_ADDR_HI)
-	dprintf(errfile, "%s    remainder = %v\n", prefix, cur->remainder);
+	dprintf(errfile, "%s    remainder = %s%v\n", prefix, X_SHOW_XALLOC(cur->remainder), cur->remainder);
     if (cur->rem_prefix || debug >= DBG_ADDR_HI)
-	dprintf(errfile, "%s    rem_prefix = %v\n", prefix, cur->rem_prefix);
+	dprintf(errfile, "%s    rem_prefix = %s%v\n", prefix, X_SHOW_XALLOC(cur->rem_prefix), cur->rem_prefix);
     if (cur->rem_suffix || debug >= DBG_ADDR_HI)
-	dprintf(errfile, "%s    rem_suffix = %v\n", prefix, cur->rem_suffix);
+	dprintf(errfile, "%s    rem_suffix = %s%v\n", prefix, X_SHOW_XALLOC(cur->rem_suffix), cur->rem_suffix);
     if (cur->local_name || debug >= DBG_ADDR_HI)
-	dprintf(errfile, "%s    local_name = %v\n", prefix, cur->local_name);
+	dprintf(errfile, "%s    local_name = %s%v\n", prefix, X_SHOW_XALLOC(cur->local_name), cur->local_name);
     if (cur->owner || debug >= DBG_ADDR_HI)
-	dprintf(errfile, "%s    owner = %v\n", prefix, cur->owner);
+	dprintf(errfile, "%s    owner = %s%v\n", prefix, X_SHOW_XALLOC(cur->owner), cur->owner);
     /* XXX if debug >= DBG_ADDR_MID then dump home, uid, and gid */
     if (cur->director || debug >= DBG_ADDR_HI)
-	dprintf(errfile, "%s    director = %v\n", prefix, cur->director ? cur->director->name : "[none]");
+	dprintf(errfile, "%s    director = %s%v\n", prefix, X_SHOW_XALLOC(cur->director), cur->director ? cur->director->name : "[none]");
     if (cur->router || debug >= DBG_ADDR_HI)
-	dprintf(errfile, "%s    router = %v\n", prefix, cur->router ? cur->router->name : "[none]");
+	dprintf(errfile, "%s    router = %s%v\n", prefix, X_SHOW_XALLOC(cur->router), cur->router ? cur->router->name : "[none]");
     if (cur->match_count != -1 || debug >= DBG_ADDR_HI)
 	dprintf(errfile, "%s    match_count = %d\n", prefix, cur->match_count);
     if (cur->transport || debug >= DBG_ADDR_HI)
-	dprintf(errfile, "%s    transport = %v\n", prefix, cur->transport ? cur->transport->name : "[none]");
+	dprintf(errfile, "%s    transport = %s%v\n", prefix, X_SHOW_XALLOC(cur->transport), cur->transport ? cur->transport->name : "[none]");
     /* XXX if debug >= DBG_ADDR_MID then dump transport hints */
     if (cur->parent) {
 	char *more_indent = xprintf("%s    ", prefix);
@@ -1781,7 +1859,7 @@ dump_addr(cur, prefix)
 	dprintf(errfile, "%s    error->info[code] = ERR_%ld\n", prefix, cur->error->info & ERR_MASK);
 	/* XXX shoudl decode flags into the C constants */
 	dprintf(errfile, "%s    error->info[flags] = 0x%lx\n", prefix, (cur->error->info & ~ERR_MASK));
-	dprintf(errfile, "%s    error->message = %s\n", prefix, cur->error->message);
+	dprintf(errfile, "%s    error->message = %s%s\n", prefix, X_SHOW_XALLOC(cur->error->message), cur->error->message);
     } else if (debug >= DBG_ADDR_HI)
 	dprintf(errfile, "%s    error = [none]\n", prefix);
 
@@ -1854,7 +1932,7 @@ main(argc, argv)
 	    }
 
 	    /* see what parse_address yields */
-	    form = parse_address(addr, &target, &remainder, (int *)0);
+	    form = parse_address(addr, &target, &remainder, (int *) NULL);
 	    if (form == LOCAL) {
 		printf("LOCAL %s\n", remainder);
 	    } else if (form == FAIL) {
@@ -1894,7 +1972,7 @@ main(argc, argv)
 	    }
 
 	    /* see what parse_address yields */
-	    form = parse_address(addr, &target, &remainder, (int *)0);
+	    form = parse_address(addr, &target, &remainder, (int *) NULL);
 	    if (form == LOCAL) {
 		printf("LOCAL %s\n", remainder);
 	    } else if (form == FAIL) {
