@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_118:addr.h,v 1.23 2004/02/06 22:12:51 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_119:addr.h,v 1.24 2004/08/18 21:55:54 woods Exp"
  */
 
 /*
@@ -170,9 +170,8 @@ extern char *build_partial_uucp_route __P((char *, char **, int));
 extern void strip_rfc822_comments __P((char *));
 extern void strip_rfc822_whitespace __P((char *));
 extern struct addr *alloc_addr __P((void));
-#ifdef not_yet
 extern void free_addr __P((struct addr *));
-#endif
+extern void free_addr_list __P((struct addr *));
 extern void insert_addr_list __P((struct addr *, struct addr **, struct error *));
 extern struct addr *remove_addr __P((struct addr *, char *, char *));
 extern struct addr *keep_matching_addrs __P((struct addr *, char *));
