@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_118:alloc.c,v 1.26 2004/01/08 23:10:07 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_119:alloc.c,v 1.27 2004/08/18 21:52:01 woods Exp"
  */
 
 /*
@@ -71,10 +71,6 @@
 /* the master block of blocks */
 static struct block master = {(struct bseg *)0, 0};
 
-/* the block for pmalloc(), prealloc() and pfree() macros */
-static struct block perm_block = {(struct bseg *)0, 0};
-struct block *perm = &perm_block;
-
 /* default block for 0 based life time */
 static struct block default_block = {(struct bseg *)0, 0};
 static struct block *def_block = &default_block;
@@ -103,7 +99,7 @@ extern void free();				/* int on SunOS */
  *
  * In the future, the x-style allocation routines will be used for
  * allocation of spaces which will be reclaimed after processing one
- * message.
+ * message -- i.e. through the block allocator.
  */
 char *
 xmalloc(size)
