@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_118:alloc.h,v 1.14 2003/12/14 22:42:42 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_119:alloc.h,v 1.15 2004/08/18 21:55:10 woods Exp"
  */
 
 /*
@@ -41,13 +41,6 @@ struct bseg {
 #define is_memory(block_ptr) ((struct block *)(block_ptr)->cnt)
 #define is_free(block_ptr) (!(struct block *)(block_ptr)->cnt)
 
-/*
- * backward compat macros for pmalloc() - XXX
- */
-#define pmalloc(size) (bmalloc((size),perm))
-#define prealloc(data,size) (brealloc((data),(size),perm))
-#define pfree(data) (bfree((data),perm))
-
 /*
  * X_CHECK - check for the xmalloc magic number
  *
@@ -67,12 +60,14 @@ struct bseg {
 		    (abort(), 0))					\
 	    : SUCCEED)
  
+#define X_IS_XALLOC(p)	(((ALIGNED_TYPE *)(p))[-1] == X_MAGIC)
+
+
 /* use these macros to panic code which should not generate a panic */
 #define X_NO_PANIC() (x_dont_panic = TRUE)
 #define X_PANIC_OKAY() (x_dont_panic = FALSE)
 
 /* external variables defined in alloc.c */
-extern struct block *perm;		/* permanent allocation block */
 extern int x_dont_panic;		/* dont panic in X_CHECK() */
 
 /* external functions defined in alloc.c */
