@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_118:bindlib.c,v 1.112 2004/04/16 20:37:48 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_119:bindlib.c,v 1.117 2004/08/23 18:35:59 woods Exp"
  */
 
 /*
@@ -29,17 +29,25 @@
  *          Generally used with an smtp transport.
  *
  *      private attribute data:
- *	    match_domains: domains to match.  Names under any of these
- *		domains will only be matched.  All other domains will
- *              never be matched.  This allows having a private DNS
- *              domain, and still utilizating a smart host.
+ *	    match_domains: domains to match.  If this attribute is set, and
+ *              if the target domain is fully qualified, then only names under
+ *              one of these domains will be matched.  All other domains will
+ *              never be matched.  This allows you to have a private DNS domain
+ *              that'll be matched and handled by a bind router instance, but
+ *              to still utilize a smart host for public DNS routing.
  *          ignore_domains: domains to ignore.  Names under any of these
- *              domains will never be matched.  This prevents expensive
- *              lookups for domains that are known not to be in the DNS.
- *          required: the domain that the host is required to be in to
- *              be matched - this is used for networks behind firewalls.
+ *              domains will never be matched.  This could be used to prevent
+ *              expensive lookups for domains that are known not to be in the
+ *              DNS.
+ *          required: the domain(s) that the MX target host is required to be
+ *              in for the to be matched.  This can be used for hosts behind
+ *              firewalls but which still see the public DNS but which can only
+ *              successfully connect to a select few MXers.
+ *              (XXX this is borked -- required should do what match_domains
+ *              does and this feature should be called valid_mx_host_domains or
+ *              similar)
  *          widen_domains: colon separated list of domains to use to
- *              extend an unmatched bare name.
+ *              extend an unmatched bare name.  XXX deprecated!
  *          mx_domains: domains for which the effect of mx_only (see below)
  *              will always be applied.  Domain list separated by colons.
  *              Negative matches can be forced using a preceding ! - this
@@ -48,10 +56,11 @@
  *          gateways: List of top domains and their relay gateways.  These
  *              are in the form <gateway>:<domain>...:+:
  *          rewrite_headers: Controls the rewriting of the header addresses.
- *              Integer, the higher the more likely it is to rewrite.
- *              Possible values are 0 (never rewrite), 1 (rewrite if
- *              required - basically if the address has been inverted)
- *              and 2 (always rewrite - tally ho etc...!).
+ *              Integer, the higher the more likely it is to rewrite.  Possible
+ *              values are 0 (never rewrite), 1 (rewrite if required -
+ *              basically if the address has been widened) and 2 (always
+ *              rewrite - tally ho etc...!).  (XXX this massive hack should be
+ *              ripped out along with widen_domains, defnames, and dns_search.)
  *          cname_limit: Sets a limit of the number of CNAMEs you can
  *              encounter while looking up an address.  This stops someone
  *              making a loop out of a couple of CNAMEs.  Default value 1.
@@ -60,23 +69,29 @@
  *          defer_no_connect:  if set and we cannot connect to the
  *              name server, try again later.  This is set by default.
  *          local_mx_okay:  if not set, an MX record which points to the
- *              local host is considered to be an error which will
- *              will cause mail to be returned to the sender.
+ *              local host is considered to be an error which will will cause
+ *              mail to be returned to the sender.  This is normally a very
+ *              desirable thing to have happen since it prevents idiots from
+ *              pointing their MXes at your hosts, but if you've been burdened
+ *              with the ordeal of dealing with a legacy wildcard MX then this
+ *              may be your only way out until you can scrap the wildcard.
  *          defnames:  append a default domain to an unqualified hostname,
- *              using the RES_DEFNAME flag to the resolver library.
- *              This is never set by default.
+ *              using the RES_DEFNAME flag to the resolver library.  This is
+ *              never set by default and it should be deprecated and removed.
  *          domain_required:  at least two name components are required
  *              in the hostname.  Setting this prevents lookups of
  *              single-component names which are unlikely to be valid
- *              hosts in the DNS (except of course localhost, but it should
+ *              hosts in the DNS (except of course localhost, but it must
  *              be matched as a local host and directed locally and never
  *              ever routed to!).
  *          mx_only:  use only MX records in matching an address.  If a
- *              host doesn't have a MX records, then don't use the A
- *              records for routing.  See also mx_domains above, which does
- *              this for named domains only. 
+ *              host doesn't have a MX records, then don't use the A records
+ *              for routing.  See also mx_domains above, which does this for
+ *              named domains only.  This is almost always the right thing to
+ *              do.  Normally a later instance of the gethostbyname router
+ *              driver will pick up plain hostnames that have only A records.
  *          dns_search:  allow the resolver to search through its domain
- *              list for matches.  Experimental - possibly not a good thing!
+ *              list for matches.  Deprecated -- not really a good thing!
  *
  * Algorithm
  *     1.   Check that the domain is not being ignored
@@ -244,7 +259,7 @@ struct mx_work_area {
     struct transport_hints * mx_hints;  /* MX hints for transport */
     struct bindlib_private * priv;      /* Pointer to router private attributes */
     struct error ** error_p;            /* Pointer to return error messages */
-    long flags;                         /* Router flags */
+    unsigned long int flags;		/* Router flags */
     int local_precedence;               /* Precedence of local host */
     int * found_server;                 /* Have we used the server */
     int * no_server;                    /* Is the server dead? */
@@ -343,10 +358,10 @@ bind_compute_domain ()
 int
 bind_check_if_canonical_host(hostnm, inet, error_p)
     char *hostnm;			/* domain name of host */
-    unsigned long inet;			/* expected internet address for host */
+    in_addr_t inet;			/* expected internet address for host */
     struct error **error_p;		/* pointer to error information */
 {
-    long save_res_options;		/* like _res.options in <resolv.h> */
+    unsigned long save_res_options;	/* like _res.options in <resolv.h> */
     const char *error_msg = NULL; 	/* pointer for error string from get_records() */
     HEADER *a_rrs;
     int a_size;
@@ -355,7 +370,7 @@ bind_check_if_canonical_host(hostnm, inet, error_p)
     int result;
     int no_a_rr;
 
-    DEBUG2(DBG_DRIVER_MID, "bind_check_if_canonical_host(%s, %s) called.\n", hostnm, inet_ntoa(inet_makeaddr((unsigned long) ntohl(inet), (unsigned long) 0)));
+    DEBUG2(DBG_DRIVER_MID, "bind_check_if_canonical_host(%s, %s) called.\n", hostnm, inet_ntoa(inet_makeaddr((in_addr_t) ntohl(inet), (in_addr_t) 0)));
 
 #ifdef RES_INIT
     /*  This initialises the resolver.  If the resolver is so old that RES_INIT
@@ -412,8 +427,16 @@ bind_check_if_canonical_host(hostnm, inet, error_p)
     while ((a_rr = getnextrr(&a_it, FALSE)) != NULL) {
 	if (EQIC(a_it.dname, hostnm)) {
 	    if (a_rr->rr_type == T_A) {
+		struct in_addr inaddr;
+
 		no_a_rr = FALSE;		/* found at least a valid A RR.... */
-		if (memcmp(a_rr->rr_data, (char *) &inet, sizeof(inet)) == 0) {
+		memcpy((char *) &(inaddr), a_rr->rr_data, sizeof(inaddr));
+		DEBUG4(DBG_DRIVER_HI, "found a DNS A record for the hostname '%s' with the address [%s] (0x%lx vs. 0x%lx)\n",
+		       hostnm,
+		       inet_ntoa(inaddr),
+		       ntohl(inaddr.s_addr),
+		       ntohl(inet));
+		if ((in_addr_t) inaddr.s_addr == inet) {
 		    result = DB_SUCCEED;	/* Oh!  I guess it was a matching A RR! */
 		}
 	    } else if (a_rr->rr_type == T_CNAME) {
@@ -434,7 +457,7 @@ bind_check_if_canonical_host(hostnm, inet, error_p)
     if (result != DB_SUCCEED && !*error_p) {
 	*error_p = not_a_canonical_host(xprintf("no DNS A records for the hostname '%s' match the address [%s]",
 						hostnm,
-						inet_ntoa(inet_makeaddr((unsigned long) ntohl(inet), (unsigned long) 0))));
+						inet_ntoa(inet_makeaddr((in_addr_t) ntohl(inet), (in_addr_t) 0))));
     } else if (no_a_rr) {
 	*error_p = not_a_canonical_host(xprintf("there are no DNS A records for the hostname '%s'", hostnm));
     } /* note we've already handled any "real" DB_NOMATCH... */
@@ -478,7 +501,7 @@ bind_check_if_local_mxs(target, local_precedence_p, error_p)
     int *local_precedence_p;
     struct error **error_p;
 {
-    long save_res_options;		/* like _res.options in <resolv.h> */
+    unsigned long save_res_options;	/* like _res.options in <resolv.h> */
     struct mx_work_area *mxdat;		/* Work area for MX operations */
     int no_server = FALSE;		/* TRUE if no server process */
     int found_server = FALSE;		/* TRUE if server process found */
@@ -669,7 +692,7 @@ bind_addr(raw_target, flags, priv, what, rt_info, error_p)
     struct rt_info *rt_info;		/* return route info here */
     struct error **error_p;		/* return lookup error here */
 {
-    long save_res_options;		/* like _res.options in <resolv.h> */
+    unsigned long save_res_options;	/* like _res.options in <resolv.h> */
     int ret;
 
     DEBUG2(DBG_DRIVER_HI, "bind_addr(%s) called from %s.\n", raw_target, what);
@@ -770,13 +793,9 @@ bind_addr_work(target, flags, priv, what, rt_info, error_p)
     /*
      * first see if the address matches one of the list of special
      * gateways.  if so, change the target to the gateway, and set
-     * the full_target to the original string so it will be passed
-     * on to the gateway.  the flag prevents subsequent updating of
-     * full_target from the DNS records.
-     *
-     * XXX where does full_target get set?
+     * orig_target to the original string so it will be passed
+     * on to the gateway.
      */
-
     if ((gateway = check_if_gatewayed(target, priv->gateways)) != NULL) {
 	orig_target = target;
 	target = COPY_STRING(gateway);
@@ -817,7 +836,7 @@ bind_addr_work(target, flags, priv, what, rt_info, error_p)
 	if (priv->required) {
 	    if (match_full_or_end_domain(priv->required, mxdat->full_target) == NULL) {
 		mx_work_area_destructor(mxdat, FALSE);
-		DEBUG1(DBG_DRIVER_HI, "target '%s' is not in one of the required domains.\n", target);
+		DEBUG1(DBG_DRIVER_HI, "MX target '%s' is not in one of the required domains.\n", target);
 		/* XXX should we modify error_p? */
 		if (orig_target) {
 		    xfree(target);
@@ -885,6 +904,7 @@ do_header_rewrites(from, to)
 
     DEBUG2(DBG_ROUTE_MID, "Header rewrite \"%s\" -> \"%s\"\n", from, to);
     while (q != NULL) {
+	/* XXX should do resent handling properly */
         if (strncmpic(q->text, "to:", (size_t) 3) == 0 ||
             strncmpic(q->text, "cc:", (size_t) 3) == 0) {
 	    DEBUG1(DBG_ROUTE_HI, "Rewriting header -- %s", q->text);
@@ -994,7 +1014,8 @@ find_mx_records (target, mxdat, allow_mangling)
         char * w;                       /* Working string */
         static struct str p;            /* region for building new string */
         static int initialised = FALSE; /* Have I initialised p yet? */
-        if (!initialised) {
+
+	if (!initialised) {
             STR_INIT(&p);
             initialised++;
         }
@@ -1435,7 +1456,9 @@ static int get_addr_hints(mxdat)
 
 		    memcpy((char *) &(inaddr), a_rr->rr_data, sizeof(inaddr));
 		    ina = inet_ntoa(inaddr);
-		    if (match_ip(ina, smtp_bad_mx_targets, ':', ';', FALSE, &reject_reason)) {
+		    if ((match_hostname(mxdat->matched_target, smtp_bad_mx_except, (char **) NULL) != MATCH_MATCHED) &&
+			match_ip(ina, smtp_bad_mx_targets, ':', ';', FALSE, &reject_reason)) {
+
 			error_msg = xprintf("The target hostname '%s' (of MX domain '%s') has an unauthorised address of [%s]%s%s",
 					    a_it.dname,
 					    mxdat->matched_target,
@@ -1484,7 +1507,7 @@ static int get_addr_hints(mxdat)
 	    DEBUG1(DBG_DRIVER_MID, "get_addr_hints: no A RR(s) found for '%s' in additional section...\n", mx_hint->exchanger);
 
             /* Go out and get an A record */
-            result = find_mx_target_a_records(mx_hint, mxdat->full_target, mx_hint->exchanger, &error_msg);
+            result = find_mx_target_a_records(mx_hint, mxdat->matched_target, mx_hint->exchanger, &error_msg);
 
             switch (result) {
         
@@ -1657,9 +1680,11 @@ static char * check_if_gatewayed (target, gateways)
 
 
 /*
- * rewrite-header - re-write an address in a header to be the
- * corrected address, possibly widened and/or re-ordered from
- * what the user typed. Used for To: and Cc: fields.
+ * XXX -- this hack should be ripped out.
+ *
+ * rewrite-header - re-write an address in a header to be the corrected
+ * address, possibly widened from what the user typed. Used for To: and Cc:
+ * fields.
  *
  * Under some circumstances smail seems to go round the loop
  * twice, so be careful not to do the job twice.
@@ -1804,10 +1829,11 @@ get_records(qname, qtype, answer, pack_size, error)
     }
     *pack_size = anslen;
 
-    answer->qdcount = ntohs((unsigned short int) answer->qdcount);
-    answer->ancount = ntohs((unsigned short int) answer->ancount);
-    answer->nscount = ntohs((unsigned short int) answer->nscount);
-    answer->arcount = ntohs((unsigned short int) answer->arcount);
+    /* XXX note that usually (sizeof(in_port_t) < sizeof(int)) */
+    answer->qdcount = ntohs((in_port_t) answer->qdcount);
+    answer->ancount = ntohs((in_port_t) answer->ancount);
+    answer->nscount = ntohs((in_port_t) answer->nscount);
+    answer->arcount = ntohs((in_port_t) answer->arcount);
 
     switch (answer->rcode) {
     case NOERROR:
@@ -1965,7 +1991,9 @@ find_mx_target_a_records(mx_hint, mx_domain, target, error)
 		}
 		memcpy((char *) &(inaddr), a_rr->rr_data, sizeof(inaddr));
 		ina = inet_ntoa(inaddr);
-		if (match_ip(ina, smtp_bad_mx_targets, ':', ';', FALSE, &reject_reason)) {
+		if ((match_hostname(mx_domain, smtp_bad_mx_except, (char **) NULL) != MATCH_MATCHED) &&
+		    match_ip(ina, smtp_bad_mx_targets, ':', ';', FALSE, &reject_reason)) {
+
 		    *error = xprintf("The target hostname '%s' (for MX domain '%s') has an unauthorised address of [%s]%s%s\n",
 				     a_it.dname, mx_domain, ina,
 				     reject_reason ? ": " : "",
@@ -2267,8 +2295,8 @@ add_mx_hint(addr, precedence, name, implicit)
 	   implicit ? "implicit" : "non-implicit", precedence, name)
     new_hint = new_mx_hint(precedence, COPY_STRING(name), implicit);
 #define mxhint(hint) ((struct mx_transport_hint *)((hint)->private))
-    while (*addr && (! EQ("mx",(*addr)->hint_name)
-                     || mxhint(*addr)->preference < precedence))
+    while (*addr && (! EQ("mx", (*addr)->hint_name) ||
+                     (mxhint(*addr)->preference < precedence)))
     {
         addr = &(*addr)->succ;
     }
