@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)src/bindlib.h:RELEASE-3_2_0_118:bindlib.h,v 1.14 2003/12/14 22:42:42 woods Exp"
+#ident	"@(#)src/bindlib.h:RELEASE-3_2_0_119:bindlib.h,v 1.15 2004/07/25 17:10:00 woods Exp"
 */
 
 /*
@@ -93,7 +93,7 @@ struct bindlib_private {
 
 #ifdef HAVE_BIND
 /* external functions defined in bindlib.c */
-extern int bind_check_if_canonical_host __P((char *, unsigned long, struct error **));
+extern int bind_check_if_canonical_host __P((char *, in_addr_t, struct error **));
 extern int bind_check_if_local_mxs __P((char *, int *, struct error **));
 extern char *bind_lookup_txt_rr __P((char *, struct error **));
 extern int bind_addr __P((char *, unsigned long, struct bindlib_private *, char *, struct rt_info *, struct error **));
