@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_118:config.h,v 1.132 2004/05/30 15:54:13 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_119:config.h,v 1.135 2004/08/23 22:22:40 woods Exp"
  */
 
 /*
@@ -700,6 +700,8 @@ ${if def:sender_host\
 	 else\
 	 	{${if origin:local\
 			{localhost}\
+		 else\
+			{localhost(non-local sender)}\
 		}}\
 	}}\
 } \
@@ -860,6 +862,17 @@ ${if and{{origin:local} {def:owner}}\
 # define BODY_CHECKS_ALWAYS	NULL
 #endif
 
+/*
+ * A list of host domain names or RE patterns for MX domains which we allow to
+ * have target hosts with addresses matching in smtp_bad_mx_targets
+ *
+ * For example on a gateway host this could be set to a list of MX domains
+ * which are handled by servers on a private Intranet.
+ */
+#ifndef SMTP_BAD_MX_EXCEPT
+# define SMTP_BAD_MX_EXCEPT	NULL
+#endif
+
 /*
  * A list of target addresses for MX records that we consider to be invalid.
  */
@@ -1019,19 +1032,43 @@ ${if and{{origin:local} {def:owner}}\
  * matter) are all automatically allowed for connections from any local
  * interface (see peer_is_localhost in smtprecv.c).
  *
- * WARNING: do not arbitrarily include $more_hostnames in this list!  Doing so
+ * WARNING: the "?:" option cannot be used to specify a non-capturing
+ * sub-expression due to the fact ':' field separators must be quoted.
+ *
+ * WARNING:  do not arbitrarily include $more_hostnames in this list!  Doing so
  * would block the hosts this server is primary MX if they used their own
  * hostnames in their PTRs and then tried to deliver mail to this server.
+ *
+ * Note iterating all the valid ISO 3166 2-letter country codes would be too
+ * much work to maintain so we just wildcard any two-letter top-level domain.
+ * If spammers start regularly violating invalid 2-letter domains then we can
+ * either reject the bogus ones explicitly or consider listing all of the valid
+ * ones....
+ *
+ * Note "arpa" is not included in the list of valid domains as there are no
+ * valid SMTP hosts possible in that domain and PTRs pointing at .ARPA are
+ * just plain bogus.
+ *
+ * See <URL:http://www.iana.org/gtld/gtld.htm> for the current list of gTLDs.
+ *
+ * WARNING:  The negated expression must come second last because the more
+ * specific messages need to match before it in order to be seen; and the
+ * wildcard entry must come last.  Any localization of this setting should be
+ * done by copying the original value and then inserting new entries at the
+ * beginning.
  */
 #ifndef SMTP_HOST_REJECT_HOSTNAMES
 # define SMTP_HOST_REJECT_HOSTNAMES	"\
-:.*\\.(?P<TLD>(local|localdomain|prv))\
-;The top level domain '%{TLD}' is not valid on the public Internet\
 :.*\\.(?P<TLD>(test|example|invalid|localhost))\
 ;The top level domain '%{TLD}' is not valid on the public Internet -- it is reserved by IANA as per RFC 2606\
 :(.*\\.)*(?P<DOM>(example\\.(com|net|org)))\
 ;The domain '%{DOM}' is not valid on the public Internet -- it is reserved by IANA as per RFC 2606\
-:${foreach:hostname:${rxquote:value};Your PTR is forged!  That is my hostname!}"
+:${foreach:hostname:${rxquote:value};Your PTR is forged!  That is my hostname!}\
+:! .*\\.(AERO|BIZ|COM|COOP|EDU|GOV|INFO|INT|MIL|MUSEUM|NAME|NET|ORG|PRO|[A-Z][A-Z])\
+;these are the valid top-level domains (this message will never be seen)\
+:.*\\.(?P<TLD>([^.]+))\
+;There is no such domain '%{TLD}' on the public Internet (your PTR is lying)!\
+"
 #endif
 
 /*
@@ -1066,19 +1103,46 @@ ${if and{{origin:local} {def:owner}}\
  * already containing a '.' need to have their leading parts be matched
  * optionally.
  *
+ * WARNING: the "?:" option cannot be used to specify a non-capturing
+ * sub-expression due to the fact ':' field separators must be quoted.
+ *
  * WARNING: do not arbitrarily include $more_hostnames in this list!  Doing so
  * would block the hosts this server MXs for from delivering to their own
  * domain names.
+ *
+ * Note we allow the internal logic to do the actual validation of domain
+ * literal address IP numbers.
+ *
+ * note iterating all the valid ISO 3166 2-letter country codes would be too
+ * much so we just wildcard any two-letter top-level domain.  If spammers start
+ * regularly violating invalid 2-letter domains then we can either reject the
+ * bogus ones explicitly or consider listing all of the valid ones....
+ *
+ * Note "arpa" is not included in this list as there are no valid SMTP hosts
+ * possible in that domain.
+ *
+ * See <URL:http://www.iana.org/gtld/gtld.htm> for the current list of gTLDs.
+ *
+ * WARNING:  The negated expression must come second last because the more
+ * specific messages need to match before them in order to be seen; and the
+ * wildcard entry must come last.  Any localization of this setting should be
+ * done by copying the original value and then inserting new entries at the
+ * beginning.
  */
 #ifndef SMTP_HELLO_REJECT_HOSTNAMES
 # define SMTP_HELLO_REJECT_HOSTNAMES	"\
-:.*\\.(?P<TLD>(local|localdomain|prv))\
-;There is no such top level domain '%{TLD}' on the public Internet!\
 :.*\\.(?P<TLD>(test|example|invalid|localhost))\
-There is no such top level domain '%{TLD}' -- it is reserved by IANA as per RFC 2606\
+;There is no such top level domain '%{TLD}' -- it is reserved by IANA as per RFC 2606\
 :(.*\\.)*(?P<DOM>(example\\.(com|net|org)))\
 ;There is no such domain '%{DOM}' -- it is reserved by IANA as per RFC 2606\
-:${foreach:hostname:${rxquote:value};That's my hostname!}"
+:${foreach:hostname:${rxquote:value};That's my hostname!}\
+:! \\[\\d+\\.\\d+\\.\\d+\\.\\d+\\]\
+;these are IP addresses (this message will never be seen)\
+:! .*\\.(AERO|BIZ|COM|COOP|EDU|GOV|INFO|INT|MIL|MUSEUM|NAME|NET|ORG|PRO|[A-Z][A-Z])\
+;these are the valid top-level domains (this message should never be seen)\
+:.*\\.(?P<TLD>([^.]+))\
+;There is no such domain '%{TLD}' on the public Internet!\
+"
 #endif
 
 /*
@@ -1181,11 +1245,12 @@ There is no such top level domain '%{TLD}' -- it is reserved by IANA as per RFC
  *
  * NOTE: this is more or less redundant with the default entries in the
  * SMTP_SENDER_REJECT_HOSTNAMES list, but it's here as well as an example.
+ *
+ * ":.+@(.*\\.)*(?P<TLD>(localhost|local|localdomain|prv|test|example|invalid(\\.)))\
+ * ;Using '%{TLD}' in an SMTP envelope address is not permitted!"
  */
 #ifndef SMTP_SENDER_REJECT
-# define SMTP_SENDER_REJECT		"\
-:.+@(.*\\.)*(?P<TLD>(localhost|local|localdomain|prv|test|example|invalid(\\.)))\
-;Using '%{TLD}' in an SMTP envelope address is not permitted!"
+# define SMTP_SENDER_REJECT		NULL
 #endif
 
 /*
@@ -1204,33 +1269,49 @@ There is no such top level domain '%{TLD}' -- it is reserved by IANA as per RFC
  * A list of host domain name REs which will cause the SMTP transaction to be
  * denied if the sender address domain matches any one of them.
  *
- * It's far better just to leave normal sender verification enabled than to try
- * to keep this list up-to-date.  However when a domain that does exist in the
- * DNS is the "source" of much abuse then adding it to this list will stop the
+ * Note that smtp_bad_mx_targets should catch the invalid domain literals.
+ *
+ * It's far better just to leave normal sender verification enabled for
+ * everyone (i.e. don't list anyone in smtp_sender_no_verify) than to try to
+ * keep this list up-to-date.  However when a domain that does exist in the DNS
+ * is the "source" of much abuse then adding it to this list will stop the
  * abuse in its tracks.
  *
  * XXX should (have) be(en) called SMTP_SENDER_REJECT_DOMAINS
  *
- * WARNING: This variable may be deprecated by the more
- *          general smtp_sender_reject in a future release.
+ * WARNING: the "?:" option cannot be used to specify a non-capturing
+ * sub-expression due to the fact ':' field separators must be quoted.
  *
- * The following example, which uses the list item negation feature, will match
- * all known valid top level domains (by wild-carding the two-letter country-
- * code TLDs because there are so many of them!)  (as of 2003/01/14)
+ * Note we use this more strict IP address matcher only as an example of how it
+ * can be done.
  *
- *  "!.+\\.(AERO|ARPA|BIZ|COM|COOP|EDU|GOV|INFO|INT|MIL|MUSEUM|NAME|NET|ORG|PRO|[A-Z][A-Z]);Your domain name is not valid!"
+ * We could probably use lookahead matching to prevent the domain literal
+ * pattern from bypassing 0.0.0.0 by inserting "(?!0+\\.0+\\.0+\\.0+\\]$)"
+ * after the first literal square bracket, but the more explicit check gives a
+ * better error message.
+ *
+ * See <URL:http://www.iana.org/gtld/gtld.htm> for the current list of gTLDs.
+ *
+ * WARNING:  The negated expressions must come second last because we the more
+ * specific messages need to match before them in order to be seen; and the
+ * wildcard entry must come last.  Any localization of this setting should be
+ * done by copying the original value and then inserting new entries at the
+ * beginning.
  */
 #ifndef SMTP_SENDER_REJECT_HOSTNAMES
 # define SMTP_SENDER_REJECT_HOSTNAMES	"\
-:(.*\\.)*localdomain;The domain 'localdomain' is not valid!\
-:(.*\\.)*local;The domain 'local' is not valid!\
-:(.*\\.)*test;The domain 'test' is not valid -- it is reserved by IANA as per RFC 2606.\
-:(.*\\.)*example;The domain 'example' is not valid -- it is reserved by IANA as per RFC 2606.\
-:(.*\\.)*invalid;The domain 'invalid' is not valid -- it is reserved by IANA as per RFC 2606.\
-:(.*\\.)*localhost;The domain 'localhost' is not valid -- it is reserved by IANA as per RFC 2606.\
-:(.*\\.)*example\\.com;The domain 'example.com' is not valid -- it is reserved by IANA as per RFC 2606.\
-:(.*\\.)*example\\.net;The domain 'example.net' is not valid -- it is reserved by IANA as per RFC 2606.\
-:(.*\\.)*example\\.org;The domain 'example.org' is not valid -- it is reserved by IANA as per RFC 2606."
+:.*\\.(?P<TLD>(test|example|invalid|localhost))\
+;The domain '%{TLD}' is not valid -- it is reserved by IANA as per RFC 2606.\
+:(.*\\.)*(?P<TLD>(example\\.(com|net|org)))\
+;The domain 'example.%{TLD}' is not valid -- it is reserved by IANA as per RFC 2606.\
+:\\[0+\\.0+\\.0+\\.0+\\]\
+;The literal IP address [0.0.0.0] cannot ever be valid.\
+:! \\[([01]\\d\\d|2[0-4]\\d|25[0-5])\\.([01]\\d\\d|2[0-4]\\d|25[0-5])\\.([01]\\d\\d|2[0-4]\\d|25[0-5])\\.([01]\\d\\d|2[0-4]\\d|25[0-5])\\]\
+;these are the valid IP addresses (this message will never be seen)\
+:! .*\\.(AERO|BIZ|COM|COOP|EDU|GOV|INFO|INT|MIL|MUSEUM|NAME|NET|ORG|PRO|[A-Z][A-Z])\
+;these are the valid top-level domains (this message should never be seen)\
+:.*\\.(?P<TLD>([^.]+))\
+;There is no such domain '%{TLD}' on the public Internet!"
 #endif
 
 /*
