@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_118:default.c,v 1.77 2004/03/18 20:36:02 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_119:default.c,v 1.79 2004/08/17 19:17:35 woods Exp"
  */
 
 /*
@@ -43,6 +43,7 @@
 #include "list.h"
 #include "smailstring.h"
 #include "dys.h"
+#include "smailsock.h"
 #include "drivertab.h"
 #include "transport.h"
 #if defined(HAVE_BIND) && defined(USE_BIND)
@@ -543,9 +544,9 @@ static struct forwardfile_private dotforward_director_priv = {
 #else
     "0-99:uucp:daemon",			/* be cautious of some forward file */
 #endif
-    /* remote access directories are very unsecure */
+    /* remotely accessible directories are very unsecure */
     REMOTE_HOMES,
-    NULL,				/* can be owned by root */
+    "root",				/* can also be owned by root */
     NULL,				/* no group ownership restriction */
     NULL,				/* no prefix */
     NULL,				/* no suffix */
@@ -556,7 +557,7 @@ static struct director dotforward_director = {
     FORWARDFILE_DIRECTOR_DRV_NM,	/* use the forwardfile driver */
     SUCC,				/* point to next director */
     /*
-     * secure source of addresses, owner should be the user, use "nobody"
+     * secure source of addresses, file owner should be the user, use "nobody"
      * for addresses returned by unsecure forward files
      */
     FWD_CHECKOWNER |
