@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_118:direct.c,v 1.48 2004/03/18 21:10:33 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_119:direct.c,v 1.49 2004/08/17 19:49:12 woods Exp"
  */
 
 /*
@@ -605,7 +605,7 @@ finish_direct_special_form(addr, dp, form, new, out, defer, fail, includes)
     struct addr *addr;			/* addr structure to finish */
     struct director *dp;		/* matching director */
     enum local_form form;		/* local address form */
-    struct addr **new;			/* UNUSED put new addrs to retry here */
+    struct addr **new GCC_UNUSED_HACK;	/* put new addrs to retry here */
     struct addr **out;			/* resolved addrs */
     struct addr **defer;		/* put config errors here */
     struct addr **fail;			/* put failed addrs here */
