@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src/directors:RELEASE-3_2_0_118:aliasfile.c,v 1.43 2004/03/18 21:10:32 woods Exp"
+#ident	"@(#)smail/src/directors:RELEASE-3_2_0_119:aliasfile.c,v 1.44 2004/07/24 16:01:05 woods Exp"
  */
 
 /*
@@ -366,7 +366,7 @@ dtd_aliasfile(dp, in, out, new, defer, fail)
 		    struct addr *defer2 = NULL;
 		    struct addr *fail2 = NULL;
 		    struct addr *okay = NULL;
-		    int was_reopen = (dp->flags & ALIAS_REOPEN); /* remember... */
+		    unsigned long int was_reopen = (dp->flags & ALIAS_REOPEN); /* remember... */
 		    int oexitval = exitvalue; /* resolve_addr_list() can clobber this */
 
 		    DEBUG1(DBG_DRIVER_MID, "dtd_aliasfile: owner is not postmaster (is '%v'), will attempt to verify.\n", preparsed_owner);
