@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src/directors:RELEASE-3_2_0_118:altuser.c,v 1.22 2004/03/18 21:10:32 woods Exp"
+#ident	"@(#)smail/src/directors:RELEASE-3_2_0_119:altuser.c,v 1.23 2004/08/17 19:49:11 woods Exp"
  */
 
 /*
@@ -170,9 +170,9 @@ dtd_altuser(dp, in, out, new, defer, fail)
     struct director *dp;		/* director entry */
     struct addr *in;			/* input local-form addrs */
     struct addr **out;			/* output resolved addrs */
-    struct addr **new;			/* UNUSED output new addrs to resolve */
+    struct addr **new GCC_UNUSED_HACK;	/*  output new addrs to resolve */
     struct addr **defer;		/* addrs to defer to a later time */
-    struct addr **fail;			/* UNUSED unresolvable addrs */
+    struct addr **fail GCC_UNUSED_HACK;	/* unresolvable addrs */
 {
     register struct addr *cur;		/* temp for processing input */
     struct addr *pass = NULL;		/* addrs to pass to next director */
