@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src/directors:RELEASE-3_2_0_118:fwdfile.c,v 1.57 2004/03/18 21:10:32 woods Exp"
+#ident	"@(#)smail/src/directors:RELEASE-3_2_0_119:fwdfile.c,v 1.58 2004/08/17 19:49:37 woods Exp"
  */
 
 /*
@@ -63,8 +63,10 @@
  *
  *	private attribute flags:
  *	    checkowner:  if set, the user associated with the forward
- *		file (remainder from the addr structure) is allowed
- *		as a possible owner for the file.
+ *		file (remainder from the addr structure) is allowed as a
+ *		possible owner for the file. (XXX perhaps we should just expand
+ *		the owners attribute so that "$user" can be included in it and
+ *		then the weird logic this flag implies wouldn't be necessary)
  *
  *	    forwardto:  if set, this is actually a Forward-to driver.
  *		In this case, the forward file is used only if the
