@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/directors:RELEASE-3_2_0_118:smartuser.c,v 1.29 2004/05/28 21:32:06 woods Exp"
+#ident	"@(#)smail/directors:RELEASE-3_2_0_119:smartuser.c,v 1.31 2004/08/22 19:33:43 woods Exp"
  */
 
 /*
@@ -34,6 +34,30 @@
  *	  it possible to have a compiled-in configuration that does not
  *	  match anything, while making it possible to enable the smartuser
  *	  driver using only a config file.
+ *
+ * TODO:  add a "cmd" attribute (which alternately uses global smart_user_cmd) which
+ *	  which will allow dynamic lookups to be done.  E.g. the following
+ *	  little script could be used to query a set of internal mailbox
+ *	  server on a private network from a gateway:
+ *
+ *		# In order to use the traditional "vrfy" and support multiple
+ *		# domains the internal DNS must point the MXs for all those
+ *		# domains at the internal mailboxes server and it would be
+ *		# invoked with the following setting:
+ *		#
+ *		# smart_user_cmd = "/local/sbin/vrfy_addr ${shquote:user}@${shquote:target_domain}"
+ *		#
+ *		if vrfy "$1" >/dev/null 2>&1; then
+ *			echo "<@mailboxes.private:$1>"
+ *		else
+ *			echo ":error:The address <$1> is not valid."
+ *		fi
+ *
+ *	  The stdout of the command will become the new_user value.
+ *
+ *	  It would be a configuration error for the command to fail, thus for
+ *	  incoming SMTP transactions this would cause a temporary recipient
+ *	  reject.
  */
 
 #include "defs.h"
@@ -132,7 +156,7 @@ dtd_smartuser(dp, in, out, new, defer, fail)
     struct addr **out;			/* output resolved addrs */
     struct addr **new;			/* output new addrs to resolve */
     struct addr **defer;		/* addrs to defer to a later time */
-    struct addr **fail;			/* UNUSED unresolvable addrs */
+    struct addr **fail GCC_UNUSED_HACK;	/* unresolvable addrs */
 {
     register struct addr *cur;		/* temp for processing input */
     struct addr *new2 = NULL;		/* addr created if prefix or suffix was stripped */
