@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src/directors:RELEASE-3_2_0_118:user.c,v 1.35 2004/05/28 21:32:05 woods Exp"
+#ident	"@(#)smail/src/directors:RELEASE-3_2_0_119:user.c,v 1.37 2004/08/17 19:49:10 woods Exp"
  */
 
 /*
@@ -115,9 +115,9 @@ dtd_user(dp, in, out, new, defer, fail)
     struct director *dp;		/* director entry */
     struct addr *in;			/* input local-form addrs */
     struct addr **out;			/* output resolved addrs */
-    struct addr **new;			/* UNUSED output new addrs to resolve */
+    struct addr **new GCC_UNUSED_HACK;	/* output new addrs to resolve */
     struct addr **defer;		/* addrs to defer to a later time */
-    struct addr **fail;			/* UNUSED unresolvable addrs */
+    struct addr **fail GCC_UNUSED_HACK;	/* unresolvable addrs */
 {
     register struct addr *cur;		/* temp for processing input */
     struct addr *new2 = NULL;		/* addr created if prefix or suffix was stripped */
@@ -147,7 +147,7 @@ dtd_user(dp, in, out, new, defer, fail)
 	     * remembering it in rem_prefix
 	     */
 	    anchored_re = xprintf("^%s", expand_string(priv->prefix, (struct addr *) NULL, (char *) NULL, (char *) NULL));
-	    if (match_re(cur->remainder, anchored_re, ignore_user_case, &start, &beg, &end, &last) != MATCH_MATCHED) {
+	    if (match_re(cur->remainder, anchored_re, (ignore_user_case ? TRUE : FALSE), &start, &beg, &end, &last) != MATCH_MATCHED) {
 		cur->succ = pass;
 		pass = cur;
 		xfree(anchored_re);
@@ -177,7 +177,7 @@ dtd_user(dp, in, out, new, defer, fail)
 		newrem = new2->remainder; /* use new value without prefix */
 	    }
 	    anchored_re = xprintf("%s$", expand_string(priv->suffix, (struct addr *) NULL, (char *) NULL, (char *) NULL));
-	    if (match_re(newrem, anchored_re, ignore_user_case, &start, &beg, &end, &last) != MATCH_MATCHED) {
+	    if (match_re(newrem, anchored_re, (ignore_user_case ? TRUE : FALSE), &start, &beg, &end, &last) != MATCH_MATCHED) {
 		cur->succ = pass;
 		pass = cur;
 		xfree(anchored_re);
