@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_118:dys.h,v 1.22 2004/06/01 00:15:34 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_119:dys.h,v 1.24 2004/06/25 17:55:49 woods Exp"
  */
 
 /*
@@ -50,7 +50,7 @@
 #define STR_GET(sp, pos)	((sp)->p[(pos)])
 
 /* STR_CHECK - call X_CHECK (from alloc.h) for a string */
-#define STR_CHECK(sp)	((sp) ? X_CHECK((sp)->p) :			\
+#define STR_CHECK(sp)	(void) ((sp) ? X_CHECK((sp)->p) :		\
 			 	(write_log(WRITE_LOG_PANIC,		\
 					   "STR_CHECK(NULL), line=%d, file=%s", \
 					   __LINE__, __FILE__),		\
@@ -143,7 +143,7 @@
 /*
  * STR_FREE - free a region, returning its storage to the free pool
  */
-#define STR_FREE(sp)	((sp)->p ? xfree((sp)->p) : 1, (sp)->p = NULL, (sp)->i = 0)
+#define STR_FREE(sp)	((sp)->p ? xfree((sp)->p) : (void) 1, (sp)->p = NULL, (sp)->i = 0)
 
 /*
  * STR_ALIGN - if region index is not aligned add bytes to align it.
