@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_118:expand.c,v 1.74 2004/04/21 19:59:31 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_119:expand.c,v 1.75 2004/07/24 16:14:00 woods Exp"
  */
 
 /*
@@ -471,7 +471,7 @@ test_cond(addr, found, sp)
     char *new;
     size_t len, len2;
     charplist_t *hdr;
-    long tpflags;
+    unsigned long int tpflags;
     struct str str;
     int result;
     int negate = FALSE;
@@ -931,7 +931,6 @@ foreach_clause(addr, str, s, es)
     char *pat_end;
     char *ss;
     char *item;
-    int result;
 
     /*
      * get the list name
@@ -958,6 +957,7 @@ foreach_clause(addr, str, s, es)
 	    q++;
 	}
 	if (q != es) {
+	    DEBUG2(DBG_CONF_LO, "foreach_clause(): junk after closing '}': '%V'\n", (size_t) (q - es), q);
 	    return FAIL;			/* XXX syntax error */
 	}
 	break;
@@ -968,6 +968,7 @@ foreach_clause(addr, str, s, es)
 	break;
     }
     if (pat == pat_end) {
+	DEBUG(DBG_CONF_LO, "foreach_clause(): empty string pattern\n");
 	return FAIL;				/* emptiness */
     }
     /* XXX should check for (unescaped?) colons in pat... */
@@ -977,12 +978,13 @@ foreach_clause(addr, str, s, es)
      */
     list = substitute(addr, (char *) NULL, (char *) NULL, listname, listname_len);
     if (!list) {
+	DEBUG2(DBG_CONF_LO, "foreach_clause(): substitute(addr, NULL, NULL, %S) failed\n", listname_len, listname);
 	return FAIL;
     }
     list = COPY_STRING(list);
     ss = rcopy(pat, pat_end);
 
-    DEBUG3(DBG_CONF_LO, "foreach_clause(): about to iterate over %S with '%v'\n", listname_len, listname, ss);
+    DEBUG3(DBG_CONF_HI, "foreach_clause(): about to iterate over %S with '%v'\n", listname_len, listname, ss);
     /*
      * for each entry in the list, expand the the string segment and append the
      * result to the output list
@@ -993,7 +995,10 @@ foreach_clause(addr, str, s, es)
 	} else {
 	    q = NULL;
 	}
-	result = expand_string_to(str, ss, addr, item);
+	if (expand_string_to(str, ss, addr, item) == FAIL) {
+	    DEBUG3(DBG_CONF_LO, "foreach_clause(): expand_string_to(str, %S, '%v') failed\n", listname_len, listname, item);
+	    return FAIL;
+	}
     }
 
     if (list) {
