@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_118:extern.h,v 1.122 2004/05/15 00:10:48 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_119:extern.h,v 1.124 2004/08/23 00:46:37 woods Exp"
  */
 
 /*
@@ -106,6 +106,7 @@ extern int smtp_accept_max;		/* max simultaneous SMTPs to accept */
 extern int smtp_accept_queue;		/* simultaneous SMTPs until queueonly */
 extern smail_bool_t smtp_allow_debug;	/* TRUE to allow DEBUG command in SMTP */
 extern smail_bool_t smtp_allow_expn;	/* TRUE to allow EXPN command in SMTP */
+extern char *smtp_bad_mx_except;	/* hostname list of bad MX exceptions */
 extern char *smtp_bad_mx_targets;	/* ip list of undesirable MX targets */
 extern char *smtp_banner;		/* smtp startup banner message */
 extern unsigned int smtp_debug_pause;	/* seconds to pause after child fork for debugger connect */
@@ -233,6 +234,7 @@ extern char *msg_max;			/* last valid char in msg_buf */
 extern char *end_msg_buf;		/* end of msg_buf */
 extern off_t msg_foffset;		/* file offset for msg_buf contents */
 extern off_t msg_size;			/* size of spool file */
+extern time_t msg_mtime;		/* last modified time of spool file */
 
 /* external variables defined in version.c */
 extern char *version_number;		/* string defining version number */
