@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_118:field.c,v 1.30 2004/02/02 03:20:18 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_119:field.c,v 1.31 2004/08/17 19:49:12 woods Exp"
  */
 
 /*
@@ -1135,7 +1135,7 @@ static int
 match_group_term(tq_anchor, tq_new, extract_q, group, error)
     struct token *tq_anchor;		/* anchor point from process_field */
     struct token **tq_new;		/* return last matched token here */
-    struct addr **extract_q;		/* UNUSED queue in which to add addresses */
+    struct addr **extract_q GCC_UNUSED_HACK; /* queue in which to add addresses */
     int group;				/* TRUE if we are processing a group */
     char **error;			/* store error message here */
 {
