@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_118:header.c,v 1.52 2004/05/14 23:31:38 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_119:header.c,v 1.53 2004/07/24 16:12:41 woods Exp"
  */
 
 /*
@@ -803,7 +803,7 @@ write_header(f, addr)
     FILE *f;				/* file to send header to */
     struct addr *addr;			/* transport */
 {
-    long flags = addr->transport->flags; /* transport flags */
+    unsigned long flags = addr->transport->flags; /* transport flags */
     charplist_t *q, *q2;		/* temp for processing header */
     int crlf = (flags & PUT_CRLF)?1:0;	/* put \r\n at end of each line? */
     char *s;
@@ -1103,11 +1103,11 @@ build_strict_header()
 	     *    qualify known domain abbreviations, if local
 	     */
 	    (*shq)->text = process_field(hq->text,
-					 strchr(hq->text, ':') + 1,
+					 (strchr(hq->text, ':') + 1),
 					 visible_name,
 					 (char *) NULL,
 					 (struct addr **) NULL,
-					 (islocal ? F_LOCAL : 0) | F_STRICT,
+					 ((islocal ? F_LOCAL : 0) | F_STRICT),
 					 &error);
 	} else if (HDREQ(to_fn, hq->text) ||
 		   HDREQ(cc_fn, hq->text) ||
@@ -1119,11 +1119,11 @@ build_strict_header()
 	     *    qualify known domain abbreviations, if local
 	     */
 	    (*shq)->text = process_field(hq->text,
-					 strchr(hq->text, ':') + 1,
+					 (strchr(hq->text, ':') + 1),
 					 visible_name,
 					 EQIC(sender_path, visible_name) ? (char *) NULL : sender_path,
 					 (struct addr **) NULL,
-					 (islocal ? F_LOCAL : 0) | F_STRICT,
+					 ((islocal ? F_LOCAL : 0) | F_STRICT),
 					 &error);
 	} else {
 	    (*shq)->text = hq->text;
