@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_118:log.c,v 1.71 2004/02/02 03:20:18 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_119:log.c,v 1.73 2004/08/18 21:55:27 woods Exp"
  */
 
 /*
@@ -667,9 +667,7 @@ write_log_va(who, fmt, ap)
 	    (void) fflush(msg_logfile);
 	    if (ferror(msg_logfile)) {
 		int oerrno = errno;
-		int fd;
 
-		fd = fileno(msg_logfile);
 		msg_logfile = NULL;
 		panic(EX_IOERR, "error writing the following message to %s/%s[%d]: %s\n%s",
 		      spool_dir, msg_log_fn, fileno(msg_logfile), strerror(oerrno), STR(&logstr));
@@ -819,6 +817,7 @@ send_log(fp, banner)
 
 	/* XXX we don't want to escape newlines, but currently dprintf()'s "%v" does so... */
 	fprintf(fp, "%s\n", (cd->message) + 1);
+	/* XXX there's no free_defer_addr() so we do it by hand */
 	xfree(cd->message);
 	xfree(cd->address);
 	if (cd->parent) {
