@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_118:main.c,v 1.108 2004/03/18 20:41:44 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_119:main.c,v 1.113 2004/08/23 23:20:54 woods Exp"
  */
 
 /*
@@ -26,6 +26,7 @@
 #include <ctype.h>
 #include <limits.h>
 #include <errno.h>
+#include <assert.h>
 #include <pwd.h>
 #include <signal.h>
 
@@ -169,6 +170,7 @@ static void parse_grade_range __P((char *, int *, int *));
 
 /* variables local to this file */
 static int report_memory_usage = FALSE;	/* if TRUE, report sbrk(0) when done */
+static unsigned long int startup_sbrk0 = 0;
 static char *arg_second_config_file = NULL; /* second config set by args */
 static char *arg_director_file = NULL;	/* director file set by args */
 static char *arg_router_file = NULL;	/* router file set by args */
@@ -199,10 +201,20 @@ main(argc, argv)
     int child;
     FILE *new_errfile;
 
+#if 0
+    assert(sizeof(unsigned long) >= sizeof(char *));
+#endif
+    startup_sbrk0 = (unsigned long) ((char *) sbrk((size_t /* intptr_t */) 0));
+
     MALLOC_DEBUG(MALLOC_DEBUG_LEVEL);
 
-    pcre_malloc = (void *) xmalloc;
-    pcre_free = (void *) xfree;
+#ifdef __STDC__
+    pcre_malloc = (void *(*)(size_t)) xmalloc;
+    pcre_free = (void (*)(void *)) xfree;
+#else
+    pcre_malloc = (void (*)()) xmalloc;
+    pcre_free = (void (*)()) xfree;
+#endif
 
     save_argv = argv;
 
@@ -259,7 +271,7 @@ main(argc, argv)
      * XXX for the latter two we should use getrusage() and choose some
      * meaningful multiplier instead of having the installer choose a limit.
      * It also might make more sense to hold off until we've loaded config
-     * files too.
+     * files too, especially if someone tries to set a big message_buf_size.
      */
     {
 	struct rlimit rl;
@@ -268,15 +280,17 @@ main(argc, argv)
 	rl.rlim_max = (rlim_t) RLIM_INFINITY;
 	(void) setrlimit(RLIMIT_CPU, &rl);
 	(void) setrlimit(RLIMIT_FSIZE, &rl);
-#if defined(DATA_RLIMIT)			/* usually in conf/os/OS_TYPE */
+
+#if defined(DATA_RLIMIT)
 	rl.rlim_cur = DATA_RLIMIT;
 #elif defined(SMALL_MEMORY)
 	rl.rlim_cur = (4 * 1024 * 1024);
 #else
-	rl.rlim_cur = (64 * 1024 * 1024);	/* generous, aren't we! */
+	rl.rlim_cur = (16 * 1024 * 1024);	/* generous, aren't we! */
 #endif	/* DATA_RLIMIT */
 	(void) setrlimit(RLIMIT_DATA, &rl);
-#if defined(STACK_RLIMIT)			/* usually in conf/os/OS_TYPE */
+
+#if defined(STACK_RLIMIT)
 	rl.rlim_cur = STACK_RLIMIT;
 #elif defined(SMALL_MEMORY)
 	rl.rlim_cur = (1024 * 1024);
@@ -351,7 +365,8 @@ main(argc, argv)
 	prog_type = PROG_RSMTP;
     } else if (EQ(program, "rogue") || EQ(program, "hack")) {
 	prog_type = PROG_ROGUE;
-    } else if (EQ(program, "..execmail") || EQ(program, "execmail")) {
+    } else if (EQ(program, "..execmail") || /* XXX ??? ".." ??? */
+	       EQ(program, "execmail")) {
 	prog_type = PROG_EXECMAIL;
     }
 
@@ -589,7 +604,9 @@ main(argc, argv)
     qualify_file = make_lib_fn(qualify_file);
     retry_file = make_lib_fn(retry_file);
     copying_file = make_lib_fn(copying_file);
-    smail = make_lib_fn(smail);
+
+    /* make sure `smail' points to a fully qualified pathname */
+    smail = make_util_fn(smail);
 
     if (error) {
 	/*
@@ -971,7 +988,7 @@ main(argc, argv)
 	       utilargs[2] ? utilargs[2] : "",
 	       utilargs[3] ? utilargs[3] : "");
 	child = open_child(utilargs, (char **) NULL, (FILE **) NULL, (FILE **) NULL, fileno(stderr),
-			   CHILD_MINENV, (unsigned int) getuid(), (unsigned int) getgid());
+			   CHILD_MINENV, (uid_t) getuid(), (gid_t) getgid());
 	if (child == -1) {
 	    if (errfile) {
 		fprintf(errfile, "%s: Cannot start %s: %s\n",
@@ -1030,11 +1047,13 @@ main(argc, argv)
      */
     if (report_memory_usage) {
 	if (errfile) {
-#if 0
-	    assert(sizeof(unsigned long) >= sizeof(void *));
-#endif
-	    (void) fprintf(errfile, "%s: sbrk(0) = %lu\n",
-			   program, (unsigned long) ((char *) sbrk((size_t /* intptr_t */) 0)));
+	    unsigned long int current_sbrk0 =  (unsigned long) ((char *) sbrk((size_t /* intptr_t */) 0));
+
+	    (void) fprintf(errfile, "%s: current sbrk(0)[%lu] - initial[%lu] = %ld\n",
+			   program,
+			   current_sbrk0,
+			   startup_sbrk0,
+			   current_sbrk0 - startup_sbrk0);
 	}
     }
     exit(force_zero_exitvalue ? 0 : exitvalue);
@@ -1351,6 +1370,13 @@ process_args(args, restrict)
 		arg = end_arg;		/* swallows complete argument */
 		break;
 
+	    case 'r':			/* set path to sender */
+		/* SCO Execmail '-r' option not applicable to smail */
+		if (prog_type == PROG_EXECMAIL) {
+		    break;
+		}
+		/* FALLTHRU */
+
 	    case 'f':			/* set path to sender */
 		if ((prog_type == PROG_RMAIL || prog_type == PROG_RSMTP) && restrict) {
 		    rmail_panic();
@@ -1379,23 +1405,12 @@ process_args(args, restrict)
 			sender = "MAILER-DAEMON";
 			error_sender = TRUE;
 			islocal = TRUE;
-		    } else if (*sender == '<') {
-			/*
-			 * If in <foo@mumble.com> form, strip enclosing
-			 * angle brackets.
-			 */
-			char *c;
-
-			c = sender + strlen(sender) - 1;
-			if (*c == '>') {
-			    *c = '\0';		/* XXX FIXME: is arg writable? */
-			    sender++;
-			}
 		    } else {
+			char *target;
 			int sender_type;
 
 			newsender = preparse_address(sender, &error);
-			if (newsender == NULL) {
+			if (! newsender) {
 			    if (errfile) {
 				dprintf(errfile,
 					"%s: error in sender name '%v': %v",
@@ -1403,16 +1418,28 @@ process_args(args, restrict)
 			    }
 			    sender = "MAILER-DAEMON";
 			    islocal = FALSE;
-			}
-			sender_type = parse_address(sender, (char **) NULL, &error, (int *) NULL);
-			if (sender_type == FAIL) {
-			    if (errfile) {
-				dprintf(errfile,
-					"%s: error in sender name '%v': %v",
-					program, sender, error);
+			} else {
+			    sender_type = parse_address(newsender, &target, &error, (int *) NULL);
+			    switch (sender_type) {
+			    case FAIL:
+				if (errfile) {
+				    dprintf(errfile,
+					    "%s: error in sender name '%v': %v",
+					    program, sender, error);
+				}
+				islocal = TRUE; /* assumptions... */
+				sender = "MAILER-DAEMON";
+				break;
+			    case LOCAL:
+				islocal = TRUE;
+				sender = newsender; /* choose preparse result */
+				break;
+			    default:
+				islocal = islocalhost(target);
+				sender = newsender; /* choose preparse result */
+				break;
 			    }
 			}
-			islocal = (sender_type == LOCAL);
 		    }
 		}
 		break;
@@ -1669,14 +1696,7 @@ process_args(args, restrict)
 		    arg_transport_file = arg;
 		    break;
 
-		case 'U':
-		    if (errfile) {
-			fprintf(errfile, "warning: this option will be changed from -oU to something else in the next release.\n");
-		    }
-		    report_memory_usage = TRUE;
-		    break;
 
-#ifdef notyet
 		case 'U':
 		    if (prog_type == PROG_RMAIL || prog_type == PROG_RSMTP) {
 			rmail_panic();
@@ -1687,7 +1707,10 @@ process_args(args, restrict)
 		    }
 		    arg_smail_util_dir = arg;
 		    break;
-#endif
+
+		case 'V':
+		    report_memory_usage = TRUE;
+		    break;
 
 		case 'X':
 		    if (prog_type == PROG_RMAIL || prog_type == PROG_RSMTP) {
@@ -1799,12 +1822,6 @@ process_args(args, restrict)
 		}
 		break;
 
-	    case 'r':			/* set path to sender */
-		/* SCO Execmail '-r' option not applicable to smail */
-		if (prog_type == PROG_EXECMAIL)
-		    break;
-		/* FALLTHRU */
-
 	    case 's':
 		mailq_summary_only = TRUE;
 		break;
