@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_118:match.c,v 1.18 2004/06/01 01:52:22 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_119:match.c,v 1.24 2004/08/26 18:39:11 woods Exp"
  */
 
 /*
@@ -17,8 +17,8 @@
  *	routines for matching values in various ways.
  *
  *	external functions:  match_re, match_ip, match_ip_net, flip_inet_addr,
- *			     match_hostname, match_re_list, compile_pcre_list,
- *			     match_pcre_list, free_pcre_list, format_pcre_list
+ *			     match_re_list, compile_pcre_list, match_pcre_list,
+ *			     free_pcre_list, format_pcre_list
  */
 
 #include "defs.h"
@@ -89,7 +89,7 @@
 
 /* functions local to this file */
 static pcre_info_t *compile_pcre_expr __P((char *, int, char *, char *, int, char **));
-static int match_pcre_expr __P((char *, size_t, pcre_info_t *, unsigned int, char **));
+static int match_pcre_expr __P((char *, size_t, pcre_info_t *, int, char **));
 static char *pcre_expand_msg __P((pcre_info_t *, char *, int *, int));
 
 
@@ -109,7 +109,7 @@ int
 match_re(key, exp, icase, start, beg, end, last)
     char *key;			/* string to match */
     char *exp;			/* RE to match against */
-    unsigned int icase;		/* ignore case? */
+    int icase;			/* ignore case? */
     char **start;		/* optional ptr to beg of match */
     char **beg;			/* optional ptr to beg of sub-expression */
     char **end;			/* optional ptr to after sub-expression */
@@ -197,18 +197,23 @@ int
 match_re_list(str, patterns, icase, reasonp)
     char *str;			/* string we are matching */
     char *patterns;		/* list of patterns we are using to match it */
-    unsigned int icase;		/* ignore case? */
+    int icase;			/* ignore case? */
     char **reasonp;		/* optional pointer for returned message string */
 {
     size_t str_len = strlen(str);
     char *ent_p;
     char *end_ent;
+    char *no_reason;
     
-    *reasonp = NULL;
-
     if (!patterns) {
+	DEBUG1(DBG_ADDR_HI, "match_re_list(): null patterns pointer, nothing to do for %v...\n", str);
 	return MATCH_NOMATCH;
     }
+    DEBUG3(DBG_ADDR_HI, "match_re_list(%v, %v, %s, %s): called...\n", str, patterns, icase ? "icase" : "0");
+    if (!reasonp) {
+	reasonp = &no_reason;
+    }
+    *reasonp = NULL;
 
     /* run through the pattern list */
     for (ent_p = patterns; /* NOTEST */ ; ent_p = end_ent + 1) {
@@ -303,19 +308,28 @@ match_re_list(str, patterns, icase, reasonp)
 		return MATCH_FAIL;
 	    }
 	    result = match_pcre_expr(str, str_len, re_info, TRUE, reasonp);
+	    /*
+	     * note that since we never pre-compile these patterns we could
+	     * just use matchresult without resetting it from re_info, but
+	     * doing it this way preserves the compile_pcre_expr() API.
+	     */
+	    matchresult = re_info->matchresult;
 	    /* note re_info->{re,msg} are reused and re_info->opts is static */
 	    xfree((char *) re_info->code);
 	    xfree((char *) re_info);
+	    re_info = NULL;
 
 	    switch (result) {
 	    case MATCH_NOMATCH:
-		/* just fall through so the end-of-list test works! */
+		/* just continue after the matching so the end-of-list test works! */
 		break;
 	    case MATCH_MATCHED:
-		DEBUG2(DBG_MAIN_MID, "match_re_list(): '%v' matched: returning %s\n",
+		DEBUG4(DBG_MAIN_MID, "match_re_list(): '%s%v' %s: returning %s\n",
+		       matchresult == MATCH_NOMATCH ? "! " : "",
 		       str,
-		       re_info->matchresult == MATCH_MATCHED ? "matched" : "NOT-matched");
-		return re_info->matchresult;
+		       result == MATCH_MATCHED ? "matched" : "notmatched",
+		       matchresult == MATCH_MATCHED ? "matched" : "NOT-matched");
+		return matchresult;
 	    case MATCH_FAIL:
 		DEBUG1(DBG_MAIN_MID, "match_re_list(): error: %s\n", *reasonp);
 		return MATCH_FAIL;
@@ -378,7 +392,7 @@ match_re_list(str, patterns, icase, reasonp)
  *
  * XXX allow_wildcard isn't actually used and should be zapped.
  */
-smail_bool_t
+unsigned int
 match_ip(ip, patterns, fldsep, msgsep, allow_wildcard, reasonp)
     /*const*/ char *ip;		/* ip address we are matching */
     /*const*/ char *patterns;	/* list of patterns we are using to match it */
@@ -391,14 +405,14 @@ match_ip(ip, patterns, fldsep, msgsep, allow_wildcard, reasonp)
     /*const*/ char *end_p;
     size_t len;
     
-    if (reasonp) {
-	*reasonp = NULL;
-    }
     if (!patterns) {
 	DEBUG1(DBG_ADDR_HI, "match_ip(): null patterns pointer, nothing to do for %v...\n", ip);
 	return FALSE;
     }
     DEBUG4(DBG_ADDR_HI, "match_ip(%v, %v, %c, %c): called...\n", ip, patterns, fldsep, msgsep);
+    if (reasonp) {
+	*reasonp = NULL;
+    }
 
     /* run through the pattern list */
     for (pat_p = patterns; /* NOTEST */ ; pat_p = end_p + 1) {
@@ -567,9 +581,9 @@ match_ip_net(ipaddr, netspec, allow_wildcard)
     char *netspec;
     int allow_wildcard;
 {
-    unsigned long dest;
-    unsigned long net;
-    unsigned long mask;
+    in_addr_t dest;
+    in_addr_t net;
+    in_addr_t mask;
     int bits = 0;
 
     DEBUG2(DBG_ADDR_HI, "match_ip_net([%v], [%v]) called...\n", ipaddr, netspec);
@@ -656,7 +670,7 @@ char *
 flip_inet_addr(inaddr)
     char *inaddr;
 {
-    unsigned long addr;		/* u_int32_t */
+    in_addr_t addr;
 
     addr = get_inet_addr(inaddr);
 
@@ -978,11 +992,15 @@ match_pcre_list(sp, len, pcre_list, do_subs, reasonp)
     char *sp;			/* string we are matching */
     size_t len;			/* length of string */
     charplist_t *pcre_list;	/* pre-compiled RE list */
-    unsigned int do_subs;	/* perform substitutions on message? */
+    int do_subs;		/* perform substitutions on message? */
     char **reasonp;		/* optional pointer for returned message string */
 {
     charplist_t *pat;
+    char *no_reason;
 
+    if (!reasonp) {
+	reasonp = &no_reason;
+    }
     *reasonp = NULL;
 
     for (pat = pcre_list; pat; pat = pat->succ) {
@@ -1027,18 +1045,18 @@ match_pcre_expr(sp, len, re_info, do_subs, reasonp)
     char *sp;			/* string we are matching */
     size_t len;			/* length of string */
     pcre_info_t *re_info;	/* RE stuff [result of compile_pcre_expr()] */
-    unsigned int do_subs;	/* perform substitutions on message? */
-    char **reasonp;		/* optional pointer for returned message string */
+    int do_subs;		/* perform substitutions on message? */
+    char **reasonp;		/* pointer for returned message string */
 {
     int rc;
     int *ovec;
 
     /* XXX using DBG_MAIN_* is a hack... should have DBG_MATCH_* */
-    DEBUG6(DBG_MAIN_HI, "match_pcre_expr(): checking RE %s%c%v%c%v\n\tagainst '%v'\n",
+    DEBUG6(DBG_MAIN_MID, "match_pcre_expr(): checking RE %s%c%v%c%v\n\tagainst '%v'\n",
 	   re_info->matchresult == MATCH_NOMATCH ? "! " : "",
 	   re_info->delim_c, re_info->re, re_info->delim_c,
 	   re_info->opts ? re_info->opts : "",
-	   sp);
+	   (debug >= DBG_MAIN_HI) ? sp : "(not shown)");
 
     ovec = (int *) xmalloc((size_t) re_info->ovecsize * sizeof(int));
     rc = pcre_exec(re_info->code, re_info->hints, sp, (int) len, 0, 0, ovec, re_info->ovecsize);
