@@ -1,6 +1,6 @@
 #! /bin/sh
 :
-#ident	"@(#)smail/src:RELEASE-3_2_0_118:mkdrivtab.sh,v 1.23 2004/01/16 22:29:49 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_119:mkdrivtab.sh,v 1.24 2004/07/25 17:21:56 woods Exp"
 
 # Script to create drivertab.[ch] and the driver directory makefiles
 # from a driver configuration file.  This script makes use of the AWK
@@ -205,7 +205,8 @@ __EOF__
 			#
 			outfile=${rest}/Makefile
 			if [ -f $outfile ]; then
-				backup=`dirname $outfile`/.`basename $outfile`
+				dir=`dirname $outfile`
+				backup=$dir/.`basename $outfile`
 				echo "Building $outfile, backup copy left in $backup ..." 1>&2
 				mv -f $outfile $backup
 			else
@@ -213,7 +214,7 @@ __EOF__
 			fi
 			cat <<__EOF__ > $outfile
 #
-#	Makefile for the $b driver library in smail
+#	Makefile for the $dir driver library in smail
 #
 
 #     #                                                   ###
@@ -230,11 +231,11 @@ __EOF__
 # YOU MUST MAKE CHANGES TO THE DRIVER CONF FILE AND REBUILD RATHER THAN
 # EDITING THIS FILE DIRECTLY.
 
-SHELL=/bin/sh
-AR=ar
-LINT=lint
-CC=cc
 ROOT=../..
+THIS_DIR=src/$dir
+
+include \${ROOT}/conf/Make.local
+
 MKDEPEND=\${ROOT}/conf/lib/mkdepend.sh
 MKDEFS=\${ROOT}/conf/lib/mkdefs.sh
 CHECKDEFS=\${ROOT}/conf/lib/checkdefs.sh
@@ -272,7 +273,7 @@ hsrc:
 
 sources: ${SRC}
 
-mkdefs ${DEFS_H} ${DEFS_SH} ${DEFS_SED}: ${ROOT}/conf/EDITME
+mkdefs defs ${DEFS_H} ${DEFS_SH} ${DEFS_SED}: ${ROOT}/conf/EDITME
 	ROOT=${ROOT} ${SHELL} ${MKDEFS}
 
 ${OBJ}:	${DEFS_SH}
@@ -285,7 +286,8 @@ depend:	${SRC} check_defs
 check_defs:
 	SHELL=${SHELL} ROOT=${ROOT} ${SHELL} ${CHECKDEFS}
 
-${ROOT}/conf/EDITME: .MAKE
+.PRECIOUS: ${ROOT}/conf/EDITME
+${ROOT}/conf/EDITME: ${DOT_MAKE}
 	cd ${ROOT}/conf && ${MAKE} EDITME
 
 clean:
@@ -298,10 +300,8 @@ clobber: clean
 	rm -f ${DEFS_SH} ${DEFS_H} ${DEFS_SED}
 	rm -f Makefile
 
-.MAKE:
-
-.PHONY: all install local-install clean local-clean clobber local-clobber depend local-depend lint mkdefs check_defs tags TAGS
-.PHONY: .MAKE csrc hsrc sources
+.PHONY: all install local-install clean local-clean clobber local-clobber depend local-depend lint mkdefs defs check_defs tags TAGS
+.PHONY: csrc hsrc sources
 __EOF__
 			if [ -f $backup ] ; then
 				if cmp $backup $outfile ; then
