@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_118:modes.c,v 1.170 2004/03/30 09:01:37 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_119:modes.c,v 1.175 2004/08/23 23:19:17 woods Exp"
  */
 
 /*
@@ -506,7 +506,7 @@ sig_unlink(sig)
  */
 static void
 set_queue_only(sig)
-    int sig;					/* UNUSED */
+    int sig GCC_UNUSED_HACK;
 {
 
 #if !(defined(UNIX_BSD) || defined(POSIX_OS)) || (defined(sun) && defined(UNIX_SYS5))
@@ -621,11 +621,7 @@ test_addresses()
 		}
 		/* unhook the failed address from the list of recipients */
 		*last_addr = next;
-#if 0
 		free_addr(cur);
-#else
-		xfree((char *) cur);
-#endif
 		continue;
 	    }
 
@@ -642,9 +638,7 @@ test_addresses()
 	fail = NULL;
 	resolve_addr_list(recipients, &deliver, &defer, &fail, TRUE);
 	print_addr_info(deliver, defer, fail);
-#if 0
 	free_addr_list(recipients);
-#endif
     }
 
     return;
@@ -752,7 +746,7 @@ perform_deliver_mail()
 	} else {
 	    if (debug) {
 		DEBUG(DBG_MAIN_LO,
-		      "-Q (queue_only) specified and message is queued\n");
+		      "-Q (queue_only) specified, or message grade out of delivery range, and message is queued\n");
 	    }
 	    close_spool();
 	    return;
@@ -988,13 +982,6 @@ deliver_mail()
     delivery_signals();
     call_transports(assigned_transports, &defer, &fail);
 
-    /*
-     * log any delivery deferrals
-     */
-    if (defer) {
-	defer_delivery(defer);
-    }
-
     /*
      * perform error notification for all failed and perhaps some deferred
      * addresses.
@@ -1050,7 +1037,7 @@ hash_predelivered_addresses()
     struct str work_address;
     char *address;			/* the address to remove */
     char *parent;			/* parent of address to remove */
-    long ecode;				/* needed by decode_x_line() */
+    unsigned long ecode;		/* needed by decode_x_line() */
     char *target;			/* Working info from parsed address */
     char *remainder;			/* Working info from parsed address */
     int  parse_flag;			/* user by parse_address */
@@ -1091,8 +1078,9 @@ hash_predelivered_addresses()
 				   &parse_flag) != LOCAL) && !islocalhost(target)) {
 		    DEBUG2(DBG_NOTIFY_MID, "Hashing out %v (%v) ... previously processed.\n", address, preparsed_address);
 		    /*
-		     * and if it is local then arrange for it to be ignored
-		     * during reprocessing
+		     * and if it is not local then arrange for it to be ignored
+		     * during reprocessing so as to avoid the costly remote DNS
+		     * lookups associated with such reprocessing
 		     */
 		    (void) add_to_hash(preparsed_address, (char *) NULL, (size_t) 0, hit_table);
 		}
@@ -1118,7 +1106,7 @@ daemon_mode()
     struct sockaddr_in from;		/* the accept socket address */
     struct servent *smtp_service;	/* smtp service file entry */
     struct hostent *hostentp;		/* host file entry */
-    unsigned int port;
+    in_port_t port;
     int accept_err_cnt = 0;
     int nsel;
     int optval = 1;
@@ -1164,7 +1152,7 @@ daemon_mode()
 	smtp_service_name = "smtp";
     }
     if (isdigit((int) smtp_service_name[0])) {
-	port = htons((unsigned short int) atoi(smtp_service_name));
+	port = htons((in_port_t) atoi(smtp_service_name));
     } else {
 	if ((smtp_service = getservbyname(smtp_service_name, "tcp")) == NULL) {
 	    panic(EX_UNAVAILABLE, "%v/tcp: unknown service", smtp_service_name);
@@ -1218,13 +1206,13 @@ daemon_mode()
      */
 
     /* XXX: optval argument is (const char *) on Solaris-2 and (void *) in Net/3 */
-    if (setsockopt(ls, SOL_SOCKET, SO_REUSEADDR, (char *)&optval, /* XXX (socklen_t) */ sizeof(optval)) < 0) {
+    if (setsockopt(ls, SOL_SOCKET, SO_REUSEADDR, (char *) &optval, (socklen_t) sizeof(optval)) < 0) {
 	write_log(WRITE_LOG_SYS, "SO_REUSEADDR on failed: %s.", strerror(errno));
 	exitvalue = EX_OSERR;
 	return;
     }
 
-    if (bind(ls, (struct sockaddr *)&sockin, /* XXX (socklen_t) */ sizeof(sockin)) < 0) {
+    if (bind(ls, (struct sockaddr *) &sockin, (socklen_t) sizeof(sockin)) < 0) {
 	write_log(WRITE_LOG_SYS, "bind() failed: %s.", strerror(errno));
 	exitvalue = EX_OSERR;
 	return;
@@ -1335,7 +1323,7 @@ daemon_mode()
     for (;;) {
 	size_t len;
 
-	DEBUG1(DBG_MAIN_MID, "listening for a new connection on port %u...\n", (unsigned int) ntohs((unsigned short int) port));
+	DEBUG1(DBG_MAIN_MID, "listening for a new connection on port %u...\n", (unsigned int) ntohs((in_port_t) port));
 
 	if (ls >= ((int) sizeof(fds_used) * 8)) {
 	    panic(EX_OSERR, "the listen file descriptor [%d] is too big for fd_set [%d bits]",
@@ -1371,7 +1359,7 @@ daemon_mode()
 	    DEBUG(DBG_MAIN_MID, "select returned with our listen socket descriptor ready...\n");
 
 	    /* get the first waiting connection... */
-	    as = accept(ls, (struct sockaddr *) &from, /* XXX (socklen_t) */ &len);
+	    as = accept(ls, (struct sockaddr *) &from, (socklen_t *) &len);
 	    /* XXX should we verify as != ls? */
 	    /*
 	     * WARNING:  On some systems len might end up as zero!
@@ -1471,7 +1459,10 @@ daemon_mode()
 # endif	/* NDEBUG */
 		if (smtp_accept_max > 0 && smtpd_accept_count >= smtp_accept_max) {
 		    static char *reject[2] = {
-			"421 ", " Too many connections; try again later.\r\n"
+			"421-",
+			/* primary_name */
+			" Too many connections; try again later.\r\n"
+			"421 Try again later.\r\n",
 		    };
 
 		    DEBUG1(DBG_MAIN_MID, "rejecting SMTP connection #%d...\n",
@@ -1480,6 +1471,8 @@ daemon_mode()
 		    (void) write(as, reject[0], strlen(reject[0]));
 		    (void) write(as, primary_name, strlen(primary_name));
 		    (void) write(as, reject[1], strlen(reject[1]));
+		    sleep(1);
+		    (void) write(as, reject[2], strlen(reject[2]));
 		    (void) close(as);
 		    /* XXX hope this doesn't get too noisy! */
 		    write_log(WRITE_LOG_SYS,
@@ -1550,12 +1543,11 @@ check_daemon_signals(ls)
 
 /*
  * do_daemon_accept - perform processing for an accepted SMTP connection
- *
- * accept SMTP commands in a separate process.
+ * (i.e. read, parse, & execute SMTP commands) in a separate process.
  */
 static void
 do_daemon_accept(ls, fd, from)
-    int ls;				/* listen socket, must be closed */
+    int ls;				/* listen socket, must be closed in child */
     int fd;				/* connected channel */
     struct sockaddr_in *from;		/* address of peer */
 {
@@ -1587,53 +1579,85 @@ do_daemon_accept(ls, fd, from)
 #endif
     fd2 = dup(fd);
     if (fd2 < 0) {
-	int sverrno = errno;
-	FILE *f;
+	int oerrno = errno;
+	static char *reject[] = {
+	    "421-",
+	    /* primary_name */
+	    " Connection temporarily refused -- system resources exausted [dup]\r\n"
+	    "421 Try again later.\r\n",
+	};
 
-	if (!(f = fdopen(fd, "w"))) {
-	    int sverrno2 = errno;
-
-	    (void) close(fd);
-	    /* XXX this may still fail if the paniclog wasn't open already */
-	    write_log(WRITE_LOG_PANIC, "fdopen() failed trying to write 421 to client [%s]: %s.",
-		      inet_ntoa(from->sin_addr), strerror(sverrno2));
-	    return;
-	}
-	dprintf(f, "421 %v Connection refused: %s\r\n",
-		primary_name, strerror(sverrno));
-	(void) fflush(f);
+	DEBUG3(DBG_MAIN_MID, "dup() failed for PID %ld: rejecting SMTP connection #%d: %s\n",
+	       (long int) getpid(), smtpd_accept_count + 1, strerror(oerrno));
+	/* use write(2) because if fdopen() failed we'd have to anyway! */
+	(void) write(fd, reject[0], strlen(reject[0]));
+	(void) write(fd, primary_name, strlen(primary_name));
+	(void) write(fd, reject[1], strlen(reject[1]));
+	sleep(1);
+	(void) write(fd, reject[2], strlen(reject[2]));
 	(void) close(fd);
+	fd = -1;
+	/* XXX hope this doesn't get too noisy, and hope it works! */
+	write_log(WRITE_LOG_SYS | WRITE_LOG_PANIC,
+		  "connection %d (from [%s]) deferred, dup() failed: %s",
+		  smtpd_accept_count + 1,
+		  inet_ntoa(from->sin_addr),
+		  strerror(oerrno));
+	exitvalue = EX_OSERR;
+
 	return;
     }
     /* don't worry about retries here -- the remote should retry for us... */
     switch (pid = fork()) {
-    case -1: {		/* fork() failed in the parent process */
+
+    case -1: {		/* fork() failed, in the parent process */
 	int oerrno = errno;
-	FILE *f = fdopen(fd, "w");	/* XXX error check this? */
+	static char *reject[] = {
+	    "421-",
+	    /* primary_name */
+	    " Connection temporarily refused -- system resources exausted [fork]\r\n"
+	    "421 Try again later.\r\n",
+	};
 
 	DEBUG3(DBG_MAIN_MID, "fork() failed for PID %ld: rejecting SMTP connection #%d: %s\n",
 	       (long int) getpid(), smtpd_accept_count + 1, strerror(oerrno));
-	write_log(WRITE_LOG_SYS, "fork() failed: %s", strerror(oerrno));
-	dprintf(f, "421 %v Connection refused -- system resources exausted\r\n",
-		primary_name);
-	(void) fflush(f);
+	/* use write(2) because if fdopen() failed we'd have to anyway! */
+	(void) write(fd, reject[0], strlen(reject[0]));
+	(void) write(fd, primary_name, strlen(primary_name));
+	(void) write(fd, reject[1], strlen(reject[1]));
+	sleep(1);
+	(void) write(fd, reject[2], strlen(reject[2]));
+	(void) close(fd);
+	fd = -1;
+	/* XXX hope this doesn't get too noisy, and hope it works! */
+	write_log(WRITE_LOG_SYS | WRITE_LOG_PANIC,
+		  "connection %d (from [%s]) deferred, fork() failed: %s",
+		  smtpd_accept_count + 1,
+		  inet_ntoa(from->sin_addr),
+		  strerror(oerrno));
+	exitvalue = EX_OSERR;
+
 	break;
     } /* end of 'case -1:' */
+
     case 0: {		/* in the child process */
 	FILE *in;			/* input channel */
 	FILE *out;			/* output channel */
 
 	if (smtp_debug_pause) {
-	    /* NOTE: the pid is included in the text so it can be seen with -v999 too! */
-	    write_log(WRITE_LOG_SYS, "remote: pausing %d seconds for debugger startup on PID %ld ....",
+	    /* NOTE: the pid is included in the text so it can be seen when using -v999 too! */
+	    write_log(WRITE_LOG_SYS | WRITE_LOG_TTY,
+		      "remote: pausing %d seconds for debugger startup on PID %ld ....",
 		      smtp_debug_pause, (long int) getpid());
 	    sleep(smtp_debug_pause);	/* XXX what about interactions with SIGALRM? */
 	}
 
+	/* close the listen socket, as we must */
 	(void) close(ls);
+
 	/* setup the channels */
-	in = fdopen(fd, "r");		/* XXX error check this? */
-	out = fdopen(fd2, "w");		/* XXX error check this? */
+	in = fdopen(fd, "r");		/* XXX error check this! */
+	out = fdopen(fd2, "w");		/* XXX error check this! */
 
 	/*
 	 * the child process may have to fork()....
@@ -1641,11 +1665,15 @@ do_daemon_accept(ls, fd, from)
 	if (set_sigchld_handler(SIG_DFL) < 0) {
 	    write_log(WRITE_LOG_SYS, "do_daemon_accept(): signal(SIGCHLD, SIG_DFL) failed: %s.", strerror(errno));
 	    exitvalue = EX_OSERR;
+	    /* XXX not fatal? */
 	}
 	/*
 	 * if the number of outstanding child processes exceeds
-	 * smtp_accept_queue, then turn on queue_only in the child,
-	 * so that mail will not be delivered immediately.
+	 * smtp_accept_queue, then turn on queue_only in the child, so that
+	 * mail will not be delivered immediately, hopefully reducing the load
+	 * somewhat (esp. on systems which need to fork delivery processes, but
+	 * even for direct delivery the immediate copying of message data is
+	 * avoided).
 	 */
 	if (smtp_accept_queue > 0 && smtpd_accept_count >= smtp_accept_queue) {
 	    /* XXX hope this doesn't get too noisy! */
@@ -1662,10 +1690,13 @@ do_daemon_accept(ls, fd, from)
 
 	/* NOTREACHED */
     } /* end of 'case 0:' */
+
     default:		/* in the parent process */
 	add_smtpd_child(pid);
 	break;
+
     } /* end of switch() */
+
     (void) close(fd);
     (void) close(fd2);
 
@@ -1684,7 +1715,7 @@ void
 daemon_mode()
 {
     if (errfile) {
-	(void) fprintf(stderr, "%s: daemon mode not supported\n", program);
+	(void) fprintf(errfile, "%s: daemon mode not supported\n", program);
 	exitvalue = EX_UNAVAILABLE;
     }
     noop_mode();
@@ -1698,7 +1729,7 @@ daemon_mode()
 /*ARGSUSED*/
 static void
 daemon_sighup(sig)
-    int sig;					/* UNUSED */
+    int sig GCC_UNUSED_HACK;
 {
 #if !(defined(UNIX_BSD) || defined(POSIX_OS)) || (defined(sun) && defined(UNIX_SYS5))
     /* reset the handler if we're using unreliable signals */
@@ -1748,7 +1779,7 @@ daemon_sigterm(sig)
  */
 static void
 daemon_sigalrm(sig)
-    int sig;					/* UNUSED */
+    int sig GCC_UNUSED_HACK;
 {
     got_sigalrm = TRUE;
     if (signal(SIGALRM, daemon_sigalrm) == SIG_ERR) {
@@ -2288,7 +2319,8 @@ print_addr_info(deliver, defer, fail)
 
 	    *p = '\0';
 	}
-	dprintf(stdout, "%v%s%v%s ... not deliverable: %v\n",
+	dprintf(stdout,
+		"%v%s%v%s ... not deliverable: %v\n",
 		in_addr,
 		top ? " (orig-to " : "",
 		top ? top->in_addr : "",
@@ -2607,11 +2639,9 @@ print_queue()
 		dprintf(stdout, "%v", cur->in_addr);
 	    }
 	}
-#if 0
 	if (recipients) {
 	    free_addr_list(recipients);
 	}
-#endif
 	if (extract_addresses) {		/* was -t in argv? */
 	    char *error;
 	    struct addr *msg_rcpts = NULL;
@@ -2650,9 +2680,7 @@ print_queue()
 		    dprintf(stdout, "%v", cur->in_addr);
 		}
 	    }
-#if 0
 	    free_addr_list(msg_rcpts);
-#endif
 	}
 	(void) putchar('\n');
 
@@ -2964,6 +2992,7 @@ process_one_spool_file(spfn)
     DEBUG1(DBG_MAIN_MID, "process_one_spool_file(%s): called\n", spfn);
 
     /* message grade is encoded in the last char of the filename */
+    /* XXX this should probably be done in open_spool(), not here! */
     msg_grade = spfn[strlen(spfn) - 1];
 
     /* initialize state before reading state from the spool file */
