@@ -1,5 +1,5 @@
 /*
- * #ident	"@(#)smail/src:RELEASE-3_2_0_118:notify.c,v 1.74 2004/01/20 08:15:36 woods Exp"
+ * #ident	"@(#)smail/src:RELEASE-3_2_0_119:notify.c,v 1.75 2004/08/17 20:00:19 woods Exp"
  */
 
 /*
@@ -67,16 +67,17 @@
 
 #include "smail.h"
 #include "config.h"
+#include "list.h"
+#include "smailstring.h"
+#include "dys.h"
 #include "parse.h"
 #include "addr.h"
 #include "main.h"
 #include "log.h"
+#include "spool.h"
 #include "direct.h"
 #include "route.h"
 #include "alloc.h"
-#include "list.h"
-#include "smailstring.h"
-#include "dys.h"
 #include "transport.h"
 #include "smailwait.h"
 #include "child.h"
@@ -106,6 +107,9 @@ static char *text_banner = "\
 
 /*
  * fail_delivery - log that delivery to the set of addresses failed
+ *
+ * XXX record in-queue delay too? -- it'll be boringly the same as the maximum
+ * retry duration for the destination
  */
 void
 fail_delivery(addr)
@@ -181,6 +185,8 @@ fail_delivery(addr)
 /*
  * defer_delivery - log that delivery to the specified addresses has been
  * deferred
+ *
+ * XXX record in-queue delay too?  Why bother?
  */
 void
 defer_delivery(addr)
@@ -277,6 +283,7 @@ succeed_delivery(addr)
 {
     register struct addr *cur;
     register struct addr *top;
+    unsigned long int delay = time((time_t *) NULL) - msg_mtime;
 
     for (cur = addr; cur; cur = cur->succ) {
 	/* find the top parent to log the original in_addr */
@@ -287,7 +294,7 @@ succeed_delivery(addr)
 	    top = NULL;
 	}
 	if (dont_deliver) {
-	    write_log(WRITE_LOG_SYS, "Debugging: don't deliver <%s>%s%v%s",
+	    write_log(WRITE_LOG_SYS, "Debugging: didn't deliver <%s>%s%v%s",
 		      quote(cur->next_addr ? cur->next_addr : cur->in_addr, FALSE, FALSE),
 		      top ? " orig-to: <" : "",
 		      top ? top->in_addr : "",
@@ -296,7 +303,7 @@ succeed_delivery(addr)
 #if (SMAIL_LOG_STYLE == 2)
 	    /* Default new log style (as of 3.1.29) */
 	    /* This is SMAIL_LOG_STYLE=2 */
-	    write_log(WRITE_LOG_SYS, "Delivered%s%v TO:%s%s%v%s%v TRANSPORT:%v",
+	    write_log(WRITE_LOG_SYS, "Delivered%s%v TO:%s%s%v%s%v TRANSPORT:%v DELAY:%s%lu",
 		      cur->next_host ? " VIA:" : "",
 		      cur->next_host ?  cur->next_host : "",
 		      quote(cur->next_addr ? cur->next_addr : cur->in_addr, FALSE, FALSE),
@@ -304,12 +311,17 @@ succeed_delivery(addr)
 		      top ? top->in_addr : "",
 		      cur->router ? " ROUTER:" : "",
 		      cur->router ? cur->router->name : "",
-		      cur->transport->name);
+		      cur->transport->name,
+		      (deliver_mode == QUEUE_MESSAGE ||
+		       queue_only ||
+		       (msg_grade < min_delivery_grade) ||
+		       (msg_grade > max_delivery_grade)) ? "Q:" : "",
+		      delay);
 #else
 # if (!defined(SMAIL_LOG_STYLE)) || (SMAIL_LOG_STYLE == 1)
 	    /* Old log style (as used by 3.1.28) */
 	    /* This is SMAIL_LOG_STYLE=1 */
-	    write_log(WRITE_LOG_SYS, "delivered%s%v\n|\t       to: %s%s%v%s%v\n|\ttransport: %v",
+	    write_log(WRITE_LOG_SYS, "delivered%s%v\n|\t       to: %s%s%v%s%v\n|\ttransport: %v\n|\tdelay: %s%lu seconds",
 		      cur->next_host ? "\n|\t      via: " : "",
 		      cur->next_host ? cur->next_host : "",
 		      quote(cur->next_addr ? cur->next_addr : cur->in_addr, FALSE, FALSE),
@@ -317,7 +329,12 @@ succeed_delivery(addr)
 		      top ? top->in_addr : "",
 		      cur->router ? "\n|\t   router: " : "",
 		      cur->router ? cur->router->name : "",
-		      cur->transport->name);
+		      cur->transport->name,
+		      (deliver_mode == QUEUE_MESSAGE ||
+		       queue_only ||
+		       (msg_grade < min_delivery_grade) ||
+		       (msg_grade > max_delivery_grade)) ? " (queued) " : "",
+		      delay);
 # else
 #  include "ERROR - SMAIL_LOG_STYLE set to invalid value."
 # endif
@@ -344,6 +361,9 @@ succeed_delivery(addr)
  * of recipients.
  *
  * detect mail sent to owners and log the original address.
+ *
+ * XXX record in-queue delay too?  It should always be very short -- just the
+ * time to discover the configuration error.
  */
 void
 error_delivery(addr)
