@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_118:pathto.c,v 1.22 2003/12/14 22:42:40 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_119:pathto.c,v 1.23 2004/08/17 19:49:12 woods Exp"
  */
 
 /*
@@ -226,8 +226,8 @@ print_pathto_addr(addr)
 /*ARGSUSED*/
 void
 optto(argc, argv)
-    int argc;				/* UNUSED */
-    char **argv;			/* UNUSED */
+    int argc GCC_UNUSED_HACK;
+    char **argv GCC_UNUSED_HACK;
 {
     (void) fprintf(stderr, "%s: optto not currently supported\n", program);
     exit(EX_UNAVAILABLE);
