@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_118:queue.c,v 1.75 2004/03/18 21:10:33 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_119:queue.c,v 1.78 2004/08/17 19:55:27 woods Exp"
  */
 
 /*
@@ -30,6 +30,7 @@
 #include <limits.h>
 #include <pwd.h>
 #include <grp.h>
+#include <time.h>
 
 #ifdef STDC_HEADERS
 # include <stdlib.h>
@@ -283,6 +284,14 @@ queue_message(f, dusage, list, errorp)
 	return FAIL;
     }
 #endif
+    /*
+     * fixup_login_user() will only update the file modify time to the last
+     * time smail touched the incoming message IFF !local_sender therefore we
+     * need to be absolutely sure it's updated again now.  This also takes into
+     * account any excessive time the header and body checks above chewed up.
+     */
+    touch(input_spool_fn, (time_t) 0, (time_t) 0);
+    msg_mtime = time((time_t *) NULL);
 
     return SUCCEED;
 }
@@ -382,6 +391,30 @@ queue_envelope(list, errorp)
 	}
     }
 
+    /* record the delivery mode that was specified for the message */
+    switch (deliver_mode) {
+    case BACKGROUND:
+	p = "-odb";
+	break;
+    case FOREGROUND:
+	p = "-odf";
+	break;
+    case QUEUE_MESSAGE:
+	p = "-odq";
+	break;
+    default:
+	p = "";
+	break;
+    }
+    if (put_line(p, errorp) == EOF) {
+	return FAIL;
+    }
+    if (queue_only) {
+	if (put_line("-Q", errorp) == EOF) {
+	    return FAIL;
+	}
+    }
+
     /* tell which form of error recover is being used */
     switch (error_processing) {
     case MAIL_BACK:
@@ -400,6 +433,7 @@ queue_envelope(list, errorp)
     if (put_line(p, errorp) == EOF) {
 	return FAIL;
     }
+
     if (dont_deliver) {
 	if (put_line("-N", errorp) == EOF) {
 	    return FAIL;
@@ -1028,7 +1062,7 @@ read_message()
 
     /* save the start position for the message */
     start_msg_body = tell_spool();
-    msg_body_size = msg_size - start_msg_body;
+    msg_body_size = (unsigned long) (msg_size - start_msg_body);
 
     DEBUG2(DBG_SPOOL_HI, "body starts at %lu, body size: %lu\n", (unsigned long) start_msg_body, msg_body_size);
 
@@ -1404,6 +1438,7 @@ log_incoming()
     char *resent_mid = NULL;		/* point to Resent-Message-Id field */
     char *mid = NULL;			/* point to Message-Id field */
     char *host_string = NULL;		/* combined host name and inet addr */
+    unsigned long int delay;
 
     for (hq = header; hq; hq = hq->succ) {
 	if (HDREQ("resent-message-id", hq->text)) {
@@ -1456,24 +1491,31 @@ log_incoming()
 	*p = '\0';
     }
 
+    delay = time((time_t *) NULL) - message_date();
 
 #if (SMAIL_LOG_STYLE == 2)
     /* Default new log style (as of 3.1.29) */
     /* This is SMAIL_LOG_STYLE=2 */
-    write_log(WRITE_LOG_SYS, "Received%s%s%s%s%s%s%s%s%s%s%s%lu%s%s%s%s",
-	      " FROM:", sender,
-	      host_string? " HOST:": "", host_string? host_string: "",
-	      sender_proto? " PROTOCOL:": "", sender_proto? sender_proto: "",
-	      " PROGRAM:", program,
-	      trim_old_id? " ORIG-ID:": "", trim_old_id? trim_old_id: "",
-	      " SIZE:", (unsigned long) msg_size,
-	      ident_sender? " IDENT:": "", ident_sender? ident_sender: "",
-	      ident_method? " ID-METHOD:": "", ident_method? ident_method: "");
+    write_log(WRITE_LOG_SYS, "Received FROM:%s%s%s%s%s PROGRAM:%s%s%s SIZE:%lu%s%s%s%s DELAY:%lu",
+	      sender,
+	      host_string ? " HOST:" : "",
+	      host_string ? host_string : "",
+	      sender_proto ? " PROTOCOL:" : "",
+	      sender_proto ? sender_proto: "",
+	      program,
+	      trim_old_id ? " ORIG-ID:" : "",
+	      trim_old_id ? trim_old_id : "",
+	      (unsigned long) msg_size,
+	      ident_sender ? " IDENT:" : "",
+	      ident_sender ? ident_sender : "",
+	      ident_method ? " ID-METHOD:" : "",
+	      ident_method ? ident_method : "",
+	      delay);
 #else
 # if (!defined(SMAIL_LOG_STYLE)) || (SMAIL_LOG_STYLE == 1)
     /* Old log style (as used by 3.1.28) */
     /* This is SMAIL_LOG_STYLE=1 */
-    write_log(WRITE_LOG_SYS, "received%s%s%s%s%s%s%s%s%s%s%s%lu%s%s%s%s%s",
+    write_log(WRITE_LOG_SYS, "received%s%s%s%s%s%s%s%s%s%s%s%lu%s%s%s%s%s%s%s%s",
 	      "\n|\t     from: ", sender,
 		host_string?
 	      "\n|\t     host: ": "", host_string? host_string: "",
@@ -1486,7 +1528,8 @@ log_incoming()
 	      ident_sender? 
 	      "\n|\t    ident: ": "", ident_sender? ident_sender: "",
 	      ident_method? 
-	      "\n|\t ident-by: ": "", ident_method? ident_method: "");
+	      "\n|\t ident-by: ": "", ident_method? ident_method: "",
+	      "\n|\tarr-delay: ", (unsigned long) msg_size, " seconds");
 # else
 #  include "ERROR -  SMAIL_LOG_STYLE set to invalid value."
 # endif
