@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_118:resolve.c,v 1.41 2004/05/16 00:27:31 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_119:resolve.c,v 1.42 2004/07/25 17:10:00 woods Exp"
  */
 
 /*
@@ -347,7 +347,7 @@ islocalhost(target)
 	if (inet_s.s_addr == htonl(INADDR_LOOPBACK)) {
 	    return TRUE;		/* obviously it must be us.... */
 	}
-	if ((hostentp = gethostbyaddr((char *) &(inet_s.s_addr), /* XXX (socklen_t) */ sizeof(inet_s.s_addr), AF_INET))) {
+	if ((hostentp = gethostbyaddr((char *) &(inet_s.s_addr), (socklen_t) sizeof(inet_s.s_addr), AF_INET))) {
 	    DEBUG2(DBG_RESOLVE_HI, "islocalhost: address literal target %s resolves to '%s'\n", target, hostentp->h_name);
 	    if (islocalhost(hostentp->h_name)) {
 	        return TRUE;
