@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_118:retry.c,v 1.67 2004/03/17 20:47:17 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_119:retry.c,v 1.69 2004/08/17 19:49:12 woods Exp"
  */
 
 /*
@@ -117,7 +117,6 @@ static struct retry *retries = NULL;	/* array of control structures */
 
 static int locked_fd = -1;
 static char *locked_path = NULL;
-static struct retry *locked_retry = NULL;
 static JUMP_ENVBUF tryfile_jmp;
 
 static struct retry *default_retry __P((void));
@@ -500,11 +499,12 @@ retry_addr_before(in, defer, fail)
 /*
  * retry_addr_after - retry processing after delivery attempt (NOP for now)
  */
+/* ARGSUSED */
 struct addr *
 retry_addr_after(started, in, fail)
-    time_t started;		/* UNUSED */
+    time_t started GCC_UNUSED_HACK;
     struct addr *in;
-    struct addr **fail;		/* UNUSED */
+    struct addr **fail GCC_UNUSED_HACK;
 {
     return in;
 }
@@ -730,7 +730,6 @@ retry_host_lock(transport, host, defer_failurep, errorp)
 	/* remember name, fd and retry parameters */
 	locked_fd = fd;
 	locked_path = COPY_STRING(tryname);
-	locked_retry = r;
     } else {
 	/* we won't be needing the lock file after all */
 	tryfile_unlock(fd);
@@ -753,7 +752,7 @@ retry_host_lock(transport, host, defer_failurep, errorp)
 /* ARGSUSED */
 void
 retry_host_unlock(started, error)
-    time_t started;			/* UNUSED */
+    time_t started GCC_UNUSED_HACK;
     struct error *error;
 {
     if (locked_fd < 0) {
@@ -776,7 +775,8 @@ retry_host_unlock(started, error)
     locked_fd = -1;
     xfree(locked_path);
     locked_path = NULL;
-    locked_retry = NULL;
+
+    return;
 }
 
 /*
@@ -809,7 +809,7 @@ static int
 allow_now(fd, tryname, spooled, started, r, error)
     int fd;
     char *tryname;
-    time_t spooled;			/* when was the msg spooled? */
+    time_t spooled GCC_UNUSED_HACK;	/* when was the msg spooled? */
     time_t started;			/* when was this lock attempt started? */
     struct retry *r;
     struct error **error;
@@ -830,7 +830,7 @@ allow_now(fd, tryname, spooled, started, r, error)
 	return TRUE;
     }
     if (r->interval == 0) {
-	interval = (queue_interval > 0) ? (queue_interval * 2) : 1;
+	interval = (time_t) ((queue_interval > 0) ? (queue_interval * 2) : 1);
     } else {
 	interval = r->interval;
     }
@@ -1138,7 +1138,7 @@ tryfile_unlock(fd)
 /* ARGSUSED */
 static void
 tryfile_alarm(sig)
-     int sig;					/* UNUSED */
+     int sig GCC_UNUSED_HACK;
 {
     JUMP_LONGJMP(tryfile_jmp, 1);
 }
