@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src/routers:RELEASE-3_2_0_118:bind.c,v 1.38 2004/02/02 03:20:16 woods Exp"
+#ident	"@(#)smail/src/routers:RELEASE-3_2_0_119:bind.c,v 1.40 2004/08/17 19:49:10 woods Exp"
  */
 
 /*
@@ -70,6 +70,7 @@
 #include "../lookup.h"
 #include "../smailstring.h"
 #include "../dys.h"
+#include "../smailsock.h"
 #include "../transport.h"
 #include "../smailconf.h"
 #include "rtlib.h"
@@ -184,7 +185,7 @@ static int
 bind_lookup(rp, addr, fl, rt_info, error_p)
     struct router *rp;			/* router table entry */
     struct addr *addr;			/* addr structure */
-    int fl;				/* UNUSED flags from rt[dv]_standard */
+    int fl GCC_UNUSED_HACK;		/* flags from rt[dv]_standard */
     struct rt_info *rt_info;		/* return route info here */
     struct error **error_p;		/* return lookup error here */
 {
