@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src/routers:RELEASE-3_2_0_118:gethost.c,v 1.39 2004/02/02 03:20:16 woods Exp"
+#ident	"@(#)smail/src/routers:RELEASE-3_2_0_119:gethost.c,v 1.40 2004/08/17 19:49:10 woods Exp"
  */
 
 /*
@@ -233,9 +233,9 @@ static int
 gethostbyname_lookup(rp, addr, fl, rt_info, error_p)
     struct router *rp;			/* router table entry */
     struct addr *addr;			/* addr structure */
-    int fl;				/* UNUSED flags from rt[dv]_standard */
+    int fl GCC_UNUSED_HACK;		/* flags from rt[dv]_standard */
     struct rt_info *rt_info;		/* return route info here */
-    struct error **error_p;		/* UNUSED return lookup error here */
+    struct error **error_p GCC_UNUSED_HACK; /* return lookup error here */
 {
     struct hostent *hostentp;		/* host file entry */
     char *copy_target;			/* copy of the target */
