@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src/routers:RELEASE-3_2_0_118:pathalias.c,v 1.29 2003/12/14 22:42:36 woods Exp"
+#ident	"@(#)smail/src/routers:RELEASE-3_2_0_119:pathalias.c,v 1.30 2004/08/17 19:49:10 woods Exp"
  */
 
 /*
@@ -298,7 +298,7 @@ static int
 pathalias_lookup(rp, addr, fl, rt_info, error_p)
     struct router *rp;			/* router table entry */
     struct addr *addr;			/* addr structure */
-    int fl;				/* UNUSED flags from rt[dv]_standard */
+    int fl GCC_UNUSED_HACK;		/* flags from rt[dv]_standard */
     struct rt_info *rt_info;		/* return route info here */
     struct error **error_p;		/* return lookup error here */
 {
@@ -379,7 +379,7 @@ pathalias_lookup(rp, addr, fl, rt_info, error_p)
 /*ARGSUSED*/
 static void
 set_parent(rp, routed, rt_info)
-    struct router *rp;				/* UNUSED */
+    struct router *rp GCC_UNUSED_HACK;
     struct addr *routed;
     struct rt_info *rt_info;
 {
