@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src/routers:RELEASE-3_2_0_118:queryprog.c,v 1.21 2004/01/20 08:15:36 woods Exp"
+#ident	"@(#)smail/src/routers:RELEASE-3_2_0_119:queryprog.c,v 1.22 2004/08/17 19:49:10 woods Exp"
  */
 
 /*
@@ -210,7 +210,7 @@ static int
 queryprogram_lookup(rp, addr, fl, rt_info, error_p)
     struct router *rp;			/* router table entry */
     struct addr *addr;			/* addr structure */
-    int fl;				/* UNUSED flags from rt[dv]_standard */
+    int fl GCC_UNUSED_HACK;		/* flags from rt[dv]_standard */
     struct rt_info *rt_info;		/* return route info here */
     struct error **error_p;		/* return lookup error here */
 {
