@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src/routers:RELEASE-3_2_0_118:rewrite.c,v 1.36 2004/02/03 22:18:52 woods Exp"
+#ident	"@(#)smail/src/routers:RELEASE-3_2_0_119:rewrite.c,v 1.37 2004/08/17 19:49:10 woods Exp"
  */
 /*
  * rewrite.c
@@ -417,7 +417,7 @@ static int
 rewrite_lookup(rp, addr, fl, rt_info, error_p)
     struct router *rp;			/* router table entry */
     struct addr *addr;			/* addr structure */
-    int fl;				/* UNUSED flags from rt[dv]_standard */
+    int fl GCC_UNUSED_HACK;		/* flags from rt[dv]_standard */
     struct rt_info *rt_info;		/* return route info here */
     struct error **error_p;		/* return lookup error here */
 {
