@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src/routers:RELEASE-3_2_0_118:smarthost.c,v 1.23 2004/01/17 21:39:50 woods Exp"
+#ident	"@(#)smail/src/routers:RELEASE-3_2_0_119:smarthost.c,v 1.24 2004/08/17 19:49:10 woods Exp"
  */
 
 /*
@@ -125,7 +125,7 @@ rtd_smarthost(rp, in, out, defer, fail)
     struct addr *in;			/* input addr structures */
     struct addr **out;			/* non-failed addr structures */
     struct addr **defer;		/* addrs to defer to a later time */
-    struct addr **fail;			/* UNUSED unresolvable addrs */
+    struct addr **fail GCC_UNUSED_HACK;	/* unresolvable addrs */
 {
     register struct addr *cur;		/* current addr being processed */
     struct addr *next;			/* next addr to process */
