@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_118:smail.h,v 1.22 2004/03/18 20:23:11 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_119:smail.h,v 1.23 2004/08/17 19:36:12 woods Exp"
  */
 
 /*
@@ -115,6 +115,13 @@ typedef unsigned long int	smail_bool_t;	/* boolean flags */
 # endif
 #endif
 
+/* adapt for GCC's lack of adherence to lint's standard ARGSUSED comment */
+#ifdef __GNUC__
+# define GCC_UNUSED_HACK	__attribute__((unused))
+#else
+# define GCC_UNUSED_HACK	/* nothing */
+#endif
+
 /* NetBSD gained strsignal(3) sometime just prior to 1.0 */
 #if defined(__NetBSD_Version__) && (__NetBSD_Version__ >= 100000000)
 # define HAVE_STRSIGNAL		1
