@@ -1,5 +1,5 @@
 /*
-#ident "@(#)smail/src:RELEASE-3_2_0_118:smailarch.h,v 1.2 2003/12/14 22:42:39 woods Exp"
+#ident "@(#)smail/src:RELEASE-3_2_0_119:smailarch.h,v 1.3 2004/07/24 16:17:24 woods Exp"
  */
 
 /*
@@ -41,7 +41,6 @@
  *
  * If BITS_PER_LONG < 32 be careful!  Along with other things, the hash_str()
  * function in hash.c will need to be changed.
- *
  */
 #define BITS_PER_LONG	(sizeof(long) * BITS_PER_CHAR)
 #define BITS_PER_INT	(sizeof(int) * BITS_PER_CHAR)
@@ -50,10 +49,10 @@
 /*
  * pointer - same size as a pointer to a structure
  *
- * Setup the typedef so that `pointer' is the same size as a pointer to
- * a structure.  On most machines, this is a long.  On some machines where
- * long is larger than an int, `pointer' is an unsigned int.  Woe to machines
- * with hardware addresses < 19 bits.  (smail might not even fit in that case!)
+ * Setup the typedef so that `pointer' is the same size as a pointer to a
+ * structure.  On most machines, this is a long.  On some machines where long
+ * is larger than an int, `pointer' is an unsigned int.  Woe to machines with
+ * hardware addresses < 19 bits.  (smail might not even fit in that case!)
  *
  * Assume:
  *	typedef long pointer_t;
@@ -74,19 +73,37 @@
  */
 typedef POINTER_TYPE pointer_t;
 
+/*
+ * BYTES_PER_ALIGN - what byte-resolution should be used for alignment
+ *
+ * Typically BYTES_PER_ALIGN should be equal to the width of the path to memory
+ * for a machine, as this is the smallest alignment for which there no
+ * performance penalty in accessing an object of any size.
+ *
+ * In general though sizeof(ALIGNED_TYPE) suffices, unless that's less than the
+ * size of pointer_t.
+ *
+ * Note Smail itself never stores float, double, or long double values in
+ * allocated storage so max(sizeof(pointer_t), sizeof(long long)) is the
+ * largest alignment value we have to worry about in terms of protecting
+ * ourselves from triggering SIGBUS.
+ */
+#define BYTES_PER_ALIGN		(sizeof(ALIGNED_TYPE))
+
 /*
  * even bytes and odd bytes
  *
- * The hash system used by hash.c (on disk and in memory) relies on the
- * fact that BYTES_PER_ALIGN (see an arch file) will align things to even
- * byte boundary.  Any hash `pointer' that refers to an odd value (2n+1)
- * is taken to mean an offset rather than a real address.  Note that odd
- * valued pointers are never dereferenced.
+ * The hash system used by hash.c (on disk and in memory) relies on the fact
+ * that BYTES_PER_ALIGN (see above) will align things to an even byte boundary.
  *
- * We need to be able to distinguish between even and odd addresses, and
- * to convert to/from even/odd addresseses.  On most machines this is a
- * trivial marco.  Brain damaged machines with brain damaged segment
- * addressing may have to form their own creative macros.
+ * Any hash `pointer' that refers to an odd value (2n+1) is taken to mean an
+ * offset rather than a real address.  Note that odd valued pointers are never
+ * dereferenced.
+ *
+ * We need to be able to distinguish between even and odd addresses, and to
+ * convert to/from even/odd addresseses.  On most machines this is a trivial
+ * macro.  Brain damaged machines with brain damaged segment addressing may
+ * have to form their own creative macros.
  *
  * Assume:
  *	#define NULL 0		<-- for the sake of this example
