@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_118:smailconf.c,v 1.99 2004/06/01 00:17:19 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_119:smailconf.c,v 1.101 2004/08/23 00:46:37 woods Exp"
  */
 
 /*
@@ -207,6 +207,7 @@ static struct attr_table conf_attributes[] = {
 /**/{ "smtp_debug", t_boolean, FA_FMT_DEPRECATED, FALSE, (tup_t *)&smtp_allow_debug, TRUE },
     { "smtp_allow_expn", t_boolean, 0, FALSE, (tup_t *)&smtp_allow_expn, TRUE },
 /**/{ "smtp_info", t_boolean, FA_FMT_DEPRECATED, FALSE, (tup_t *)&smtp_allow_expn, TRUE },
+    { "smtp_bad_mx_except", t_string, FA_FMT_IS_LIST, NULL, (tup_t *)&smtp_bad_mx_except, 0 },
     { "smtp_bad_mx_targets", t_string, FA_FMT_IS_LIST, NULL, (tup_t *)&smtp_bad_mx_targets, 0 },
     { "smtp_banner", t_string, 0, NULL, (tup_t *)&smtp_banner, 0 },
     { "smtp_debug_pause", t_int, 0, 0, (tup_t *)&smtp_debug_pause, 0 },
@@ -689,7 +690,8 @@ format_attribute(conf_attr, name, quoted, prefix, value, ptr, flags)
 	break;
 
     case t_boolean: {
-	int v2;
+	unsigned long int v2;
+
 	/* Booleans are handled a bit differently in the drivers */
 	if (conf_attr->offset != 0) {
 	    /* If offset is non-zero, then use it as a mask on flags */
