@@ -1,5 +1,5 @@
 /*
-#ident "@(#)smail/src:RELEASE-3_2_0_118:smailport.h,v 1.7 2004/03/18 20:22:50 woods Exp"
+#ident "@(#)smail/src:RELEASE-3_2_0_119:smailport.h,v 1.8 2004/06/25 17:53:34 woods Exp"
  */
 
 /*
@@ -120,6 +120,21 @@
 #if !defined(uid_t) && !defined(HAVE_TYPE_UID_T)
 # define uid_t		unsigned int
 #endif
+#if !defined(ssize_t) && !defined(HAVE_TYPE_SSIZE_T)
+# define ssize_t	long			/* a signed version of size_t */
+#endif
+#if !defined(blkcnt_t) && !defined(HAVE_TYPE_BLKCNT_T)
+# define ssize_t	long			/* a signed version of size_t */
+#endif
+#if !defined(in_addr_t) && !defined(HAVE_TYPE_IN_ADDR_T)
+# define in_addr_t	unsigned long int	/* XXX true for most 32-bit systems */
+#endif
+#if !defined(in_port_t) && !defined(HAVE_TYPE_IN_PORT_T)
+# define in_port_t	unsigned short int	/* XXX true for most 32-bit systems */
+#endif
+#if !defined(socklen_t) && !defined(HAVE_TYPE_SOCKLEN_T)
+# define socklen_t	unsigned int		/* XXX true for most 32-bit systems */
+#endif
 
 /* 
  * Local Variables:
