@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_118:spool.c,v 1.69 2004/04/21 23:19:09 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_119:spool.c,v 1.71 2004/08/17 19:57:11 woods Exp"
  */
 
 /*
@@ -154,6 +154,7 @@ char *msg_max;				/* last valid char in msg_buf */
 char *end_msg_buf;			/* end of msg_buf */
 off_t msg_foffset;			/* file offset for msg_buf contents */
 off_t msg_size;				/* size of spool file */
+time_t msg_mtime;			/* last modified time of spool file */
 
 /* types local to this file */
 struct log_msgs {			/* XXX this shouldbe replaced by charplist_t */
@@ -226,6 +227,7 @@ creat_spool()
     next_log_msg = &log_msgs;
     msg_foffset = 0;
     msg_size = 0;
+    msg_mtime = time((time_t *) NULL);
     if (msg_buf == NULL) {
 	/* allocate the spool i/o buffer if it does not yet exist */
 	msg_buf = xmalloc(message_bufsiz);
@@ -419,22 +421,22 @@ static void
 build_spool_fn(grade_char)
     int grade_char;
 {
-    /* store the actual spool file basename here */
-    static char fn[SPOOL_FN_LEN + 1];
-    /* name of spool file in input directory */
-    static char ifn[sizeof("input/") + SPOOL_FN_LEN];
-    /* store the lock file name here */
-    static char lfn[sizeof("lock/") + SPOOL_FN_LEN];
+    static char fn[SPOOL_FN_LEN + 1];	/* store the actual spool file basename here */
+					/* this is 14 chars which should work on all UN*X systems */
+    static char ifn[sizeof("input/") + SPOOL_FN_LEN]; /* name of spool file in input directory */
+    static char lfn[sizeof("lock/") + SPOOL_FN_LEN]; /* store the lock file name here */
     time_t now = time((time_t *) NULL);
     struct stat statbuf;
     char a_inode[8];			/* ASCII base 62 inode number (+ spare byte) */
 
-    /* get the inode number in base 62 information */
+    /* get the inode number of the temp_fn in base 62 notation */
     (void) fstat(spoolfile, &statbuf);
     (void) strcpy(a_inode, base62((unsigned long) statbuf.st_ino));
 
-    /* this is 14 chars which should work on all UN*X systems */
+    /* point global spool_fn basename pointer at static array above */
     spool_fn = fn;
+
+    /* form the full basename using BASE-62 time and BASE-62 inode + msg grade */
     (void) sprintf(spool_fn, "%s-%s%c", base62((unsigned long) now), a_inode, grade_char);
 
     /* use this to build the path in the input directory */
@@ -443,6 +445,7 @@ build_spool_fn(grade_char)
 
     /* have the message-ID computed from the computed spool file name */
     build_message_id();
+
     if (lock_by_name) {
 	lock_fn = lfn;
 	(void) sprintf(lock_fn, "lock/%s", spool_fn);
@@ -939,6 +942,8 @@ write_spool(errorp)
 	xfree(old_spool_dir);
     }
     msg_size += msg_max - msg_buf;
+    /* silly but effective, though perhaps unnecessary (see queue_message()) */
+    msg_mtime = time((time_t *) NULL);
 
     if (accepted_msg_size >= 0 && msg_size >= accepted_msg_size) {
 	*errorp = xprintf("write_spool: message grew larger than allowed [%ld]\n", accepted_msg_size);
@@ -1191,17 +1196,17 @@ static int
 copy_old_spool()
 {
     char *tempbuf = xmalloc(message_bufsiz);
-    off_t copied = 0;			/* count of chars copied to new file */
+    size_t copied = 0;			/* count of chars copied to new file */
 
     /*
      * previous contents exist, we will need to copy them
      */
     (void) lseek(old_spoolfile, (off_t) 0L, SEEK_SET);
-    while (copied < msg_size) {
-	register long ct;
+    while ((off_t) copied < msg_size) {
+	register size_t ct;
 
 	/* fill up as much of the temp buffer as reasaonble */
-	if (msg_size - copied < (off_t) message_bufsiz) {
+	if (msg_size - copied < message_bufsiz) {
 	    ct = msg_size - copied;
 	} else {
 	    ct = message_bufsiz;
@@ -1216,12 +1221,13 @@ copy_old_spool()
 	    xfree(tempbuf);
 	    return READ_FAIL;		/* read error - can't recover */
 	} else {
-	    if (write(spoolfile, tempbuf, (size_t) ct) < ct) {
+	    if (write(spoolfile, tempbuf, (size_t) ct) < (ssize_t) ct) {
 		failed_write();
 		xfree(tempbuf);
 		return WRITE_FAIL;	/* write error - maybe can recover */
 	    }
 	}
+	/* XXX we shouldn't have to check for overflow here... but... */
 	copied += ct;
     }
     xfree(tempbuf);
@@ -1365,7 +1371,7 @@ open_spool(fn, lock, logopts)
     }
 
     /*
-     * Get statistics on spool file.
+     * Get inode info for the spool file.
      */
     if (fstat(spoolfile, &statbuf) < 0) {
 	write_log(logopts, "open_spool: %s/%s: spool file fstat() error: %s",
@@ -1401,6 +1407,7 @@ open_spool(fn, lock, logopts)
     msg_max = msg_buf;
     msg_ptr = msg_buf;
     msg_size = statbuf.st_size;
+    msg_mtime = statbuf.st_mtime;
 
     if (lock) {
 	DEBUG3(operation_mode == PRINT_QUEUE ? DBG_SPOOL_MID : DBG_SPOOL_LO, /* XXX not really necessary */
@@ -1669,7 +1676,7 @@ read_spool()
     msg_foffset += msg_max - msg_buf;
     if ((off_t) message_bufsiz > msg_size - msg_foffset) {
 	/* the remaining size is less then a whole buffer */
-	ct = msg_size - msg_foffset;
+	ct = (long) (msg_size - msg_foffset);
 	if (ct < 0) {
 	    errno = ENXIO;		/* reading beyond end of the file */
 	    DEBUG1(DBG_SPOOL_LO, "read_spool: read failed, msg_foffset of '%lu' is past end of file",
@@ -1684,7 +1691,7 @@ read_spool()
 	}
     } else {
 	/* there is enough data to fit in a complete buffer */
-	ct = message_bufsiz;
+	ct = (long) message_bufsiz;
     }
 
     /* now, where were we? */
@@ -2022,7 +2029,7 @@ spool_max_free_space()
     long max_free_kbytes = -1;		/* max free space in any spoo_dir */
     long free_kbytes;			/* free space in a given spool_dir */
     long reserved_kbytes;		/* free space to reserve (kb) */
-    unsigned long blocks_free;
+    blkcnt_t blocks_free;
     unsigned long block_size;
     int result;				/* stat*fs() return code */
 # ifdef HAVE_STATVFS
@@ -2055,7 +2062,7 @@ spool_max_free_space()
 	 */
 	reserved_kbytes = 10 * 1024;
 	DEBUG1(DBG_SPOOL_LO,
-	       "spool_max_free_space: max_message_size == 0 && smtp_accept_max == 0, defaulting to reserve of %ld kbytes\n",
+	       "spool_max_free_space: smtp_accept_max == 0, defaulting to reserve of %ld kbytes\n",
 	       reserved_kbytes);
     }
     while (dirs && *dirs) {
@@ -2111,7 +2118,7 @@ spool_max_free_space()
 # endif
 	DEBUG3(DBG_SPOOL_MID,
 	       "spool_max_free_space: %s: [bfree=%lu, bsize=%lu]\n",
-	       dirname, blocks_free, block_size);
+	       dirname, (unsigned long) blocks_free, block_size);
 	/*
 	 * try desparately to avoid overflowing ulong, and never return more
 	 * than (LONG_MAX / 1024) Kbytes (since it will be multiplied out to
@@ -2123,16 +2130,16 @@ spool_max_free_space()
 	    continue;				/* avoid divide by zero */
 	}
 	if (block_size >= 1024 || blocks_free >= 1024) {
-	    unsigned long little1 = MIN(block_size, blocks_free);
-	    unsigned long big1 = MAX(block_size, blocks_free);
+	    blkcnt_t little1 = MIN((blkcnt_t) block_size, blocks_free);
+	    blkcnt_t big1 = MAX((blkcnt_t) block_size, blocks_free);
 
 	    if ((little1 * (big1 / 1024)) / little1 != (big1 / 1024)) {
 		free_kbytes = LONG_MAX / 1024;	/* even Kbytes overflowed, just go for LONG_MAX */
 	    } else {
-	        free_kbytes = MIN((little1 * (big1 / 1024)), (LONG_MAX / 1024));
+	        free_kbytes = MIN((long) (little1 * (big1 / 1024)), (LONG_MAX / 1024));
 	    }
 	} else {
-	    free_kbytes = MIN(((block_size * blocks_free) / 1024), (LONG_MAX / 1024));
+	    free_kbytes = MIN((long) ((block_size * blocks_free) / 1024), (LONG_MAX / 1024));
 	}
 	if (free_kbytes > max_free_kbytes) {
 	    max_free_kbytes = free_kbytes;
