@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_118:string.c,v 1.69 2004/05/26 06:00:16 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_119:string.c,v 1.70 2004/07/24 15:55:07 woods Exp"
  */
 
 /*
@@ -645,8 +645,6 @@ c_dequote(p, val)
  *
  * %S is akin to %.*s where a maximum length parameter is given before the
  * %string, but the length parameter is of type size_t, not int.
- * XXX if we could assume a typedef for ssize_t were available then we would
- * use that instead as it is a signed variant of size_t
  *
  * %v and %V which are like %s and %S but also turn unprintable characters into
  * C-style quotes using str_c_quote(..., dospaces=FALSE, ...).
@@ -684,7 +682,8 @@ str_printf_va(sp, fmt, ap)
 {
     register int c;			/* current char in fmt */
     register int islong;                /* to handle %ld */
-    long n;				/* temp */
+    unsigned long int un;		/* temp */
+    long int n;				/* temp */
     char *s;				/* temp */
     size_t len;				/* for %S */
     char *ofmt = fmt;			/* original format string */
@@ -740,19 +739,19 @@ str_printf_va(sp, fmt, ap)
 		STR_NEXT(sp, va_arg(ap, int));
 		break;
 	    case 'o':
-		n = islong ? va_arg(ap, unsigned long) : (unsigned long) va_arg(ap, unsigned int);
-		STR_CAT(sp, bltoa(8, (unsigned long) n));
+		un = islong ? va_arg(ap, unsigned long) : (unsigned long) va_arg(ap, unsigned int);
+		STR_CAT(sp, bltoa(8, un));
 		break;
 	    case 'x':
-		n = islong ? va_arg(ap, unsigned long) : (unsigned long) va_arg(ap, unsigned int);
-		STR_CAT(sp, bltoa(16, (unsigned long) n));
+		un = islong ? va_arg(ap, unsigned long) : (unsigned long) va_arg(ap, unsigned int);
+		STR_CAT(sp, bltoa(16, un));
 		break;
 	    case 'u':
-		n = islong ? va_arg(ap, unsigned long) : (unsigned long) va_arg(ap, unsigned int);
-		STR_CAT(sp, bltoa(10, (unsigned long) n));
+		un = islong ? va_arg(ap, unsigned long) : (unsigned long) va_arg(ap, unsigned int);
+		STR_CAT(sp, bltoa(10, un));
 		break;
 	    case 'd':
-		n = islong ? va_arg(ap, long) : (unsigned long) va_arg(ap, int);
+		n = islong ? va_arg(ap, long) : va_arg(ap, int);
 		if (n < 0) {
 		    STR_NEXT(sp, '-');
 		    n = -n;
@@ -1105,8 +1104,8 @@ time_t
 ivaltol(s)
     register char *s;			/* string containing queue interval */
 {
-    unsigned long ret = 0;		/* return value */
-    unsigned long cur = 0;		/* value of current part */
+    long ret = 0;			/* return value */
+    long cur = 0;			/* value of current part */
 
     while (*s) {
 	switch (*s++) {
@@ -1198,7 +1197,7 @@ ivaltol(s)
 	return -1L;
     }
 
-    return ret + cur;			/* all done */
+    return (ret + cur);			/* all done */
 }
 
 /*
@@ -1282,9 +1281,10 @@ rcopy(s, e)
 /*
  * make_lib_fn - build a filename relative to the smail lib directory
  *
- * If the filename begins with '/' or is "-" return it unmodified.
+ * If the filename begins with '/' or is "-" return a verbatim copy of it.
+ *
  * Return NULL if smail_lib_dir is undefined, or if the given
- *  filename is NULL.
+ * filename is NULL.
  */
 char *
 make_lib_fn(fn)
@@ -1302,6 +1302,30 @@ make_lib_fn(fn)
     return xprintf("%s/%s", smail_lib_dir, fn);
 }
 
+
+/*
+ * make_util_fn - build a filename relative to the smail util directory
+ *
+ * If the filename begins with '/' or is "-" return a verbatim copy of it.
+ *
+ * Return NULL if smail_util_dir is undefined, or if the given
+ * filename is NULL.
+ */
+char *
+make_util_fn(fn)
+    char *fn;				/* filename to expand */
+{
+    if (fn == NULL) {
+	return NULL;
+    }
+    if (fn[0] == '/' || (fn[0] == '-' && fn[1] == '\0')) {
+	return COPY_STRING(fn);
+    }
+    if (smail_util_dir == NULL) {
+	return NULL;
+    }
+    return xprintf("%s/%s", smail_util_dir, fn);
+}
 /* 
  * Local Variables:
  * c-file-style: "smail"
