@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_118:sysdep.c,v 1.116 2004/04/12 23:59:46 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_119:sysdep.c,v 1.120 2004/08/22 19:33:10 woods Exp"
  */
 
 /*
@@ -19,8 +19,9 @@
  *			    fopen_as_user, lock_file, unlock_file,
  *			    compute_hostname, compute_domain,
  *                          open_child, close_child,
- *			    close_all, scan_dir, fcntl_rd_lock, touch,
- *			    fsetsize, set_sigchld_handler
+ *			    close_all, scan_dir, fcntl_rd_lock, touch, fsetsize,
+ *			    vfprintf, strerror, strysexit, strsignal, sig2str,
+ *			    set_sigchld_handler
  */
 
 #include "defs.h"
@@ -131,10 +132,6 @@
 # include <sys/timeb.h>
 #endif
 
-#if defined(INCLUDE_VFORK_H)
-# include <vfork.h>
-#endif
-
 #include "smail.h"
 #include "smailarch.h"
 #include "smailsock.h"
@@ -243,32 +240,43 @@ extern int errno;
 /*
  * time_stamp - return a time stamp string in the form:
  *
- *	mm/dd/yyyy hh:mm:ss
+ *	yyyy/dd/dd hh:mm:ss
+ *
+ * XXX this isn't really a system dependent function, and was not even before
+ * the days of POSIX....
  */
 char *
 time_stamp()
 {
     time_t curtime = time((time_t *) NULL);
     struct tm *ltm = localtime(&curtime);
+#ifndef USE_OLD_TIMESTAMP
+    /*
+     * not exactly ISO-8601 but close, the T becomes a space so as to preserve
+     * field counts & offsets in logs, etc.
+     */
+    static char timebuf[sizeof("yyyy/mm/dd hh:mm:ss")];
+
+    (void) sprintf(timebuf, "%04d/%02d/%02d %02d:%02d:%02d",
+		   ltm->tm_year + 1900, ltm->tm_mon + 1, ltm->tm_mday,
+		   ltm->tm_hour, ltm->tm_min, ltm->tm_sec);
+#else
+    /* old stupid format */
     static char timebuf[sizeof("mm/dd/yyyy hh:mm:ss")];
 
     (void) sprintf(timebuf, "%02d/%02d/%04d %02d:%02d:%02d",
-		   ltm->tm_mon+1, ltm->tm_mday, ltm->tm_year + 1900,
+		   ltm->tm_mon + 1, ltm->tm_mday, ltm->tm_year + 1900,
 		   ltm->tm_hour, ltm->tm_min, ltm->tm_sec);
+#endif
+
     return timebuf;
 }
 
-/*
- * strings used by the date and time routines below
- */
-static char *week_day[] = {"Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat"};
-static char *months[] = {
-    "Jan", "Feb", "Mar", "Apr", "May", "Jun",
-    "Jul", "Aug", "Sep", "Oct", "Nov", "Dec",
-};
-
 /*
  * get_local_year - get the year according to local time
+ *
+ * XXX this isn't really a system dependent function, and was not even before
+ * the days of POSIX....
  */
 int
 get_local_year()
@@ -280,8 +288,20 @@ get_local_year()
 	return ((localtime(&stamp))->tm_year + 1900);
 }
 
+/*
+ * strings used by get_arpa_date()
+ */
+static char *week_day[] = {"Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat"};
+static char *months[] = {
+    "Jan", "Feb", "Mar", "Apr", "May", "Jun",
+    "Jul", "Aug", "Sep", "Oct", "Nov", "Dec",
+};
+
 /*
  * get_arpa_date - return date in RFC822 format
+ *
+ * XXX this isn't really a system dependent function, and was not even before
+ * the days of POSIX....
  */
 char *
 get_arpa_date(sometime)
@@ -310,6 +330,9 @@ get_arpa_date(sometime)
 
 /*
  * get_time_zone - get the current timezone
+ *
+ * XXX this isn't really a system dependent function, and was not even before
+ * the days of POSIX....
  */
 /* ARGSUSED */
 static char *
@@ -384,6 +407,9 @@ struct tm *ltm;
  * unix_date - get the current date as suitable for a From_ line
  *
  * Use ctime format.
+ *
+ * XXX this isn't really a system dependent function, and was not even before
+ * the days of POSIX....
  */
 char *
 unix_date()
@@ -401,6 +427,9 @@ unix_date()
 
 /*
  * compute_local_sender - compute the user running this program.
+ *
+ * XXX this isn't really a system dependent function, and was not even before
+ * the days of POSIX....
  */
 void
 compute_local_sender()
@@ -440,6 +469,9 @@ compute_local_sender()
  * getfullname - get the full name of the sender
  *
  * The full name comes from the GCOS field in the password entry.
+ *
+ * XXX this isn't really a system dependent function, and was not even before
+ * the days of POSIX....
  */
 void
 getfullname()
@@ -460,6 +492,9 @@ getfullname()
  * fullname_from_gcos - fill in sender_name from the given gcos field
  *
  * (Modified to strip 0000-name(0000) USG junk - hargen@pdn 8/20/88
+ *
+ * XXX this isn't really a system dependent function, and was not even before
+ * the days of POSIX....
  */
 static void
 fullname_from_gcos(gecos)
@@ -1350,8 +1385,7 @@ compute_domain(hostname)
  * inputs:
  *	argv	- a vector suitable for passing to execve.  argv[0] is
  *		  given as the program to exec.  If argv is NULL, then
- *		  do a return instead of an exec.  In this case as well,
- *		  never to a vfork(), always use fork().
+ *		  do a return instead of an exec.
  *	envp	- a vector of environment variables suitable for passing
  *		  to execve.  If envp is null and CHILD_MINENV is not
  *		  set in flags, then the parents environment will be
@@ -1364,7 +1398,7 @@ compute_domain(hostname)
  *		  is created, with the read-end returned in this
  *		  variable and with the write-end tied to the stdout
  *		  of the child process.
- *	errfd	- if errfd >= 0 then it sepecifies a file descriptor
+ *	errfd	- if errfd >= 0 then it specifies a file descriptor
  *		  to duplicate to the stdout and/or stderr of the
  *		  child.  If out != NULL, errfd is only dup'd to the
  *		  stderr.
@@ -1884,13 +1918,8 @@ close_all()
  */
 int
 rename(from, to)
-#ifdef ANSI_C
     const char *from;			/* old file name */
     const char *to;			/* new file name */
-#else
-    char *from;				/* old file name */
-    char *to;				/* new file name */
-#endif
 {
     struct stat statbuf;
 
@@ -2104,7 +2133,11 @@ int
 fsetsize(fd, wantsize, oversize)
     int fd;			/* fd to adjust */
     off_t wantsize;		/* desired size */
-    off_t oversize;		/* bytes not to overwrite UNUSED #ifndef F_FREESP */
+    off_t oversize		/* bytes not to overwrite */
+#ifndef F_FREESP
+	GCC_UNUSED_HACK
+#endif
+	;
 {
     off_t cursize;
 
