@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_118:transport.c,v 1.56 2004/03/18 20:32:50 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_119:transport.c,v 1.57 2004/08/05 23:03:18 woods Exp"
  */
 
 /*
@@ -470,12 +470,19 @@ call_transports(asn, defer, fail)
 	}
     }
 
+    /*
+     * log any delivery deferrals after all transports have had their say
+     */
+    if (defer) {
+	defer_delivery(*defer);
+    }
+
     /* if there are shadow deliveries to be made, assign them and transport */
     if (shadow_list == NULL) {
 	return;				/* no shadows, just return */
     }
 
-    /* assign shadow deliveries */
+    /* assign shadow transports, if any, and perform deliveries */
     for (sh_asn = assign_transports(shadow_list);
 	 sh_asn;
 	 sh_asn = sh_asn->succ)
