@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src/transports:RELEASE-3_2_0_118:appendfile.c,v 1.56 2004/03/18 21:10:32 woods Exp"
+#ident	"@(#)smail/src/transports:RELEASE-3_2_0_119:appendfile.c,v 1.58 2004/08/17 19:49:09 woods Exp"
  */
 
 /*
@@ -813,7 +813,7 @@ restore_atime(fname, atime)
 /* ARGSUSED */
 static void
 notify_comsat(tp, mbox, offset)
-    struct transport *tp;			/* UNUSED! */
+    struct transport *tp GCC_UNUSED_HACK;
     char *mbox;
     off_t offset;
 {
@@ -857,7 +857,7 @@ notify_comsat(tp, mbox, offset)
 #if defined(HAVE_SENDTO_WITH_3RD_PARAM_INT)
     ret = sendto(fd, msg, (int) (strlen(msg) + 1), 0, (struct sockaddr *) &sa, sizeof(sa));
 #else
-    ret = sendto(fd, msg, (size_t) (strlen(msg) + 1), 0, (struct sockaddr *) &sa, /* XXX (socklen_t) */ sizeof(sa));
+    ret = sendto(fd, msg, (size_t) (strlen(msg) + 1), 0, (struct sockaddr *) &sa, (socklen_t) sizeof(sa));
 #endif
     xfree(msg);
     if (ret == -1) {
