@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src/transports:RELEASE-3_2_0_118:smtplib.c,v 1.76 2004/03/17 20:47:51 woods Exp"
+#ident	"@(#)smail/src/transports:RELEASE-3_2_0_119:smtplib.c,v 1.77 2004/08/17 19:49:09 woods Exp"
  */
 
 /*
@@ -1609,7 +1609,7 @@ rfc821_quote_local_part(lp)
 /* ARGSUSED */
 static void
 catch_timeout(signo)
-    int signo;					/* UNUSED */
+    int signo GCC_UNUSED_HACK;
 {
     JUMP_LONGJMP(timeout_buf, 1);
 }
