@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src/transports:RELEASE-3_2_0_118:tcpsmtp.c,v 1.82 2004/03/18 20:27:23 woods Exp"
+#ident	"@(#)smail/src/transports:RELEASE-3_2_0_119:tcpsmtp.c,v 1.84 2004/08/17 19:49:09 woods Exp"
  */
 
 /*
@@ -791,13 +791,13 @@ set_timeout(timeout, attr)
 /* ARGSUSED */
 static int
 tcpsmtp_connect(remote_host, ip_addr, family, service, error)
-    char *remote_host;				/* UNUSED */
+    char *remote_host GCC_UNUSED_HACK;
     struct in_addr *ip_addr;
     int family;
     char *service;
     char **error;
 {
-    static unsigned short port = 0;	/* port to connect to (XXX in_port_t) */
+    static in_port_t port = 0;		/* port to connect to */
     struct servent *smtp_service;       /* service entry */
     struct sockaddr_in saddrin;		/* inet socket address */
     static char *save_error = NULL;     /* keep handle to free error msgs */
@@ -806,7 +806,7 @@ tcpsmtp_connect(remote_host, ip_addr, family, service, error)
 
     if (isdigit((int) *service)) {
         error_text = NULL;
-        port = htons((unsigned short) c_atol(service, &error_text));
+        port = htons((in_port_t) c_atol(service, &error_text));
 	/* XXX we should do more range checking than just this! */
         if (error_text) {
             *error = xprintf("invalid port: %v: %s", service, error_text);
@@ -845,7 +845,7 @@ tcpsmtp_connect(remote_host, ip_addr, family, service, error)
 	lsaddrin.sin_family = family;
 	lsaddrin.sin_port = 0;		/* any old port will do.... */
 	DEBUG2(DBG_DRIVER_MID, "\n   binding socket to local source addr (%v)[%s]... ", sending_name, inet_ntoa(lsaddrin.sin_addr));
-	if (bind(s, (struct sockaddr *) &lsaddrin, /* XXX (socklen_t) */ sizeof(lsaddrin)) < 0) {
+	if (bind(s, (struct sockaddr *) &lsaddrin, (socklen_t) sizeof(lsaddrin)) < 0) {
 	    if (save_error) {
 		xfree(save_error);
 	    }
@@ -862,7 +862,7 @@ tcpsmtp_connect(remote_host, ip_addr, family, service, error)
     DEBUG3(DBG_DRIVER_HI, "\n   connecting socket to %s[%s]/%d... ",
 	   remote_host, inet_ntoa(saddrin.sin_addr), ntohs(saddrin.sin_port));
 
-    if (connect(s, (struct sockaddr *) &saddrin, /* XXX (socklen_t) */ sizeof(saddrin)) < 0) {
+    if (connect(s, (struct sockaddr *) &saddrin, (socklen_t) sizeof(saddrin)) < 0) {
         if (save_error) {
             xfree(save_error);
         }
