@@ -1,6 +1,6 @@
 #! /bin/sh
 :
-#ident	"@(#)smail/util:RELEASE-3_2_0_118:checkerr.sh,v 1.48 2004/06/01 01:22:49 woods Exp"
+#ident	"@(#)smail/util:RELEASE-3_2_0_119:checkerr.sh,v 1.50 2004/08/23 22:24:17 woods Exp"
 #
 #    Copyright (C) 1987, 1988 Ronald S. Karr and Landon Curt Noll
 #    Copyright (C) 1992  Ronald S. Karr
@@ -464,13 +464,24 @@ mailq -s >> ${TMPDIR}/.chkerr.msg 2>&1
 	    double_bounce="`sed -n -e '/^$/q' -e '1,/^!-f$/d;/<>/p;/<\+>/p;q' error/${bounce}`"
 
 	    # If this message is a double-bounce then find the
-	    # destination address for it is about to deleted.  The
-	    # destination address is actually the sender address
-	    # for the original un-deliverable message which cannot
-	    # now be returned and is thus a double-bounce.  This
-	    # list of sender addresses can be used to reject
-	    # future e-mails from these obviously bogus or broken
-	    # sender addresses.
+	    # destination address for it as it is about to deleted.
+	    #
+	    # The destination address is actually the sender address
+	    # for the original un-deliverable message which cannot now
+	    # be returned and is thus a double-bounce.  This list of
+	    # sender addresses can be used to reject future e-mails
+	    # from these obviously bogus or broken sender addresses.
+	    #
+	    # Note that we don't care here if the sender is "local" or
+	    # not since we couldn't deliver this bounce to it and it
+	    # contained known unwanted content.  There is though some
+	    # minor chance that if this host is a gateway to an
+	    # internal server that rejected the bounce because of
+	    # content then we might end up adding a valid internal
+	    # user's address.  The correct solution here is to make
+	    # sure this gateway implements the same policies as the
+	    # internal server so that it doesn't get itself into such
+	    # a situation in the first place.
 	    #
 	    # We assume there's only ever one recipient for a bounce.
 	    #
@@ -583,12 +594,18 @@ q' error/$f`"
 	    # This is a really nasty hack but it's the best I can think of!
 	    #
 	    addrinfo="`$SMAIL_PROGRAM -v -bv ${sender} 2>&1`"
-	    count=`expr "${addrinfo}" : '.*director .*')`
+	    dir_count=`expr "${addrinfo}" : '.*director .*')`
+	    # note: don't depend on the rewrite router being called "rewrite"...
+	    rew_count=`expr "${addrinfo}" : '.*reparse address .*')`
 	    echo ""
-	    if [ $count -gt 0 ]; then
+	    if [ $dir_count -gt 0 ]; then
 		echo "WARNING: This message is a double bounce from a local original sender."
 		echo "The address <${sender}> was not deliverable."
 		echo "This message should be unfrozen when the problem has been resolved."
+	    elif [ $rew_count -gt 0 ]; then
+		echo "WARNING: This message is a double bounce from a virtual-host sender."
+		echo "The address <${sender}> was not deliverable."
+		echo "This message should be unfrozen when the problem has been resolved."
 	    else
 		echo "Note: This message is a double bounce from a non-local original sender."
 		echo "Logging sender address <${sender}> as invalid."
