@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/util:RELEASE-3_2_0_118:mkdbm.c,v 1.38 2004/02/06 22:07:38 woods Exp"
+#ident	"@(#)smail/util:RELEASE-3_2_0_119:mkdbm.c,v 1.40 2004/08/18 08:21:14 woods Exp"
  */
 
 /*
@@ -87,6 +87,7 @@
 #include "addr.h"
 #include "smailstring.h"
 #include "dys.h"
+#include "smailsock.h"
 #include "route.h"
 #include "bindlib.h"
 #include "transports/smtplib.h"			/* rfc821_is_*() decls. */
@@ -130,7 +131,7 @@ static void add_yp_stamps __P((void));
 /*ARGSUSED*/
 int
 main(argc, argv)
-    int argc;					/* UNUSED */
+    int argc GCC_UNUSED_HACK;
     char **argv;
 {
     char **files;
@@ -587,7 +588,7 @@ rename_database(from, to)
 /*ARGSUSED*/
 char *
 qualify_domain(s)
-    char *s;					/* UNUSED */
+    char *s GCC_UNUSED_HACK;
 {
     return NULL;
 }
@@ -606,14 +607,14 @@ bind_compute_domain ()
 
 int
 rfc821_is_dot_string(s)
-    char *s;				/* UNUSED */
+    char *s GCC_UNUSED_HACK;
 {
     return 0;
 }
 
 int
 rfc821_is_quoted_string(s)
-    char *s;				/* UNUSED */
+    char *s GCC_UNUSED_HACK;
 {
     return 0;
 }
