@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/util:RELEASE-3_2_0_118:mksort.c,v 1.20 2004/02/02 03:20:15 woods Exp"
+#ident	"@(#)smail/util:RELEASE-3_2_0_119:mksort.c,v 1.21 2004/08/18 08:21:14 woods Exp"
  */
 
 /*
@@ -75,7 +75,7 @@ static int read_lines __P((struct str *, FILE *));
 /*ARGSUSED*/
 int
 main(argc, argv)
-    int argc;					/* UNUSED */
+    int argc GCC_UNUSED_HACK;
     char **argv;
 {
     struct str strings;
