@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/util:RELEASE-3_2_0_118:unsharmap.c,v 1.30 2004/02/06 22:07:38 woods Exp"
+#ident	"@(#)smail/util:RELEASE-3_2_0_119:unsharmap.c,v 1.32 2004/08/18 08:21:13 woods Exp"
  */
 /*
  *    Copyright (C) 1988 Ronald S. Karr and Landon Curt Noll
@@ -109,6 +109,7 @@
 #include "addr.h"
 #include "smailstring.h"
 #include "dys.h"
+#include "smailsock.h"
 #include "route.h"
 #include "bindlib.h"
 #include "transports/smtplib.h"			/* rfc821_is_*() decls. */
@@ -308,7 +309,7 @@ main( argc, argv )
     logit(err);
     exit( (errors>0) ? 4 : 0 );
 
-    /* NOTERACHED */
+    /* NOTREACHED */
 }
 
 
@@ -847,7 +848,7 @@ check_newline( str )
 /*ARGSUSED*/
 char *
 qualify_domain(s)
-    char *s;				/* UNUSED */
+    char *s GCC_UNUSED_HACK;
 {
     return NULL;
 }
@@ -866,14 +867,14 @@ bind_compute_domain ()
 
 int
 rfc821_is_dot_string(s)
-    char *s;				/* UNUSED */
+    char *s GCC_UNUSED_HACK;
 {
     return 0;
 }
 
 int
 rfc821_is_quoted_string(s)
-    char *s;				/* UNUSED */
+    char *s GCC_UNUSED_HACK;
 {
     return 0;
 }
